# Generic macros
#---------------
%define name castor
%define version 2.1.9
%define release 8

# Partial compilations
#---------------------
%{expand:%define compiling_nostk  %(if [ -z $CASTOR_NOSTK ]; then echo 0; else echo 1; fi)}
%{expand:%define compiling_client %(if [ -z $CASTOR_CLIENT ]; then echo 0; else echo 1; fi)}

# Python definitions
#-------------------
%define _python_lib %(python -c "from distutils import sysconfig; print sysconfig.get_python_lib()")

# General settings
#-----------------
Summary: Cern Advanced mass STORage
Name: %{name}
Version: %{version}
Release: %{release}
Source: %{name}-%{version}-%{release}.tar.gz
URL: http://cern.ch/castor
License: http://cern.ch/castor/DIST/CONDITIONS
Group: Application/Castor
BuildRoot: %{_builddir}/%{name}-%{version}-root
ExclusiveOs: linux
ExclusiveArch: i686 x86_64

# RPM specific definitions
#-------------------------
# Should unpackaged files in a build root terminate a build?
%define __check_files %{nil}
# Don't build debuginfo packages
%define debug_package %{nil}
# Prevents binaries stripping
%define __spec_install_post %{nil}
# Falls back to original find_provides and find_requires
%define _use_internal_dependency_generator 0

%description
The CASTOR Project stands for CERN Advanced STORage Manager, and its goal is to handle LHC data in a fully distributed environment.

%prep
%setup -q

%build
# In case makedepend is not in the PATH
PATH=${PATH}:/usr/X11R6/bin
export PATH
# define castor version (modified by maketar.sh to put the exact version)
MAJOR_CASTOR_VERSION=2.1
MINOR_CASTOR_VERSION=9.8
export MAJOR_CASTOR_VERSION
export MINOR_CASTOR_VERSION
make -f Makefile.ini Makefiles
(cd h; ln -s . shift)
%if 0%{?clientonly:1} > 0
%define compiling_client 1
%endif
%if %compiling_nostk
echo "Compiling in NOSTK mode, that is only tape part with no STK dependency"
make -j $((`grep processor /proc/cpuinfo | wc -l`*2)) tape
# XXX to be removed when parallel compilation is fixed
make tape
%else
%if %compiling_client
echo "Only compiling client part"
make -j $((`grep processor /proc/cpuinfo | wc -l`*2)) client
# XXX to be removed when parallel compilation is fixed
make client
%else
make -j $((`grep processor /proc/cpuinfo | wc -l`*2))
# XXX to be removed when parallel compilation is fixed
make
%endif
%endif

%install
# define castor version (modified by maketar.sh to put the exact version)
MAJOR_CASTOR_VERSION=2.1
MINOR_CASTOR_VERSION=9.8
export MAJOR_CASTOR_VERSION
export MINOR_CASTOR_VERSION
rm -rf ${RPM_BUILD_ROOT}
%if %compiling_nostk
make installtape DESTDIR=${RPM_BUILD_ROOT} EXPORTMAN=${RPM_BUILD_ROOT}/usr/share/man
%else
%if %compiling_client
make installclient DESTDIR=${RPM_BUILD_ROOT} EXPORTMAN=${RPM_BUILD_ROOT}/usr/share/man
%else
make install DESTDIR=${RPM_BUILD_ROOT} EXPORTMAN=${RPM_BUILD_ROOT}/usr/share/man
%endif
%endif

%if ! %compiling_nostk

%clean
rm -rf $RPM_BUILD_ROOT
rm -rf $RPM_BUILD_DIR/%{name}-%{version}

# The following will be filled dynamically with the rule: make rpm, or make tar
%if ! %compiling_client
%package -n castor-sacct
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate
%description -n castor-sacct
castor (Cern Advanced STORage system) - Contains a logrotate for accounting files
%files -n castor-sacct
%defattr(-,root,root)
%attr(-,root,bin) %dir /var/log/castor
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-sacct
%pre -n castor-sacct
# Move old log files to /var/log/castor
if [ -d /var/spool/sacct ]; then
    /bin/mkdir /var/log/castor 2>/dev/null
    /bin/mv /var/spool/sacct/sacct* /var/log/castor/ 2>/dev/null
    # Correct the selinux context of the new log files
    if [ -x /usr/bin/chcon ]; then
      /usr/bin/chcon -R --reference=/var/log/castor /var/log/castor > /dev/null 2>&1
    fi
    # Remove old log directory
    /bin/rm -rf /var/spool/sacct 2>/dev/null || :
fi
%endif

%if ! %compiling_client
%package -n castor-config
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-config
castor (Cern Advanced STORage system) - castor.conf example
%files -n castor-config
%defattr(-,root,root)
%attr(0644,root,root) /etc/castor/castor.conf.example
%endif

%package -n castor-devel
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib
%description -n castor-devel
castor (Cern Advanced STORage system) - API
%files -n castor-devel
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man3/Cgetopt.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cglobals.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cgrp.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cmutex.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_access.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_chclass.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_chdir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_chmod.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_chown.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_closedir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_creat.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_delcomment.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_delete.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_deleteclass.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_delsegbycopyno.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_dropsegs.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_enterclass.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_getcomment.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_getcwd.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_getsegattrs.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_lastfseq.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_listclass.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_listtape.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_mkdir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_modifyclass.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_opendir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_queryclass.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_readdir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_readdirc.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_readdirx.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_readdirxc.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_readdirxt.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_rename.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_replaceseg.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_rewinddir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_rmdir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_selectsrvr.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_setatime.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_setcomment.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_setfsize.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_setsegattrs.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_stat.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_tapesum.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_umask.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_undelete.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_unlink.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_unlinkbyvid.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_updateseg_checksum.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_updateseg_status.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_updatefile_checksum.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cns_utime.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cpool.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cpwd.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Csched.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Csetprocname.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_dmpfil.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_info.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_kill.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_label.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_mount.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_position.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_reserve.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_rls.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_rstatus.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Ctape_status.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cthread.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cupv_add.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cupv_check.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cupv_delete.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cupv_list.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cupv_modify.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/Cuuid.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/dlf_init.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/dlf_write.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/dlf_regtext.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/dlf_shutdown.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/expert_receive_data.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/expert_send_data.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/expert_send_request.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/getacct.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/getacctent.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/getcompstat.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/getconfent.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/log.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/netclose.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/netread.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/netwrite.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/readlbl.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_access.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_chmod.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_chown.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_close.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_closedir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fchmod.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fclose.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_feof.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_ferror.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fflush.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fileno.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fopen.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fopen64.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fread.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fseek.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fseeko64.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fstat.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fstat64.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_ftell.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_ftello64.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_fwrite.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_lockf.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_lockf64.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_lseek.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_lseek64.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_lstat.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_lstat64.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_mkdir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_mstat.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_mstat64.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_msymlink.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_munlink.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_open.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_open64.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_opendir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_pclose.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_perror.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_popen.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_preseek.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_preseek64.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_read.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_readdir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_readlink.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_rename.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_rewinddir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_rmdir.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_serror.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_stat.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_stat64.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_statfs.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_symlink.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_unlink.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfio_write.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfioreadopt.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rfiosetopt.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rmc_dismount.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rmc_export.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rmc_find_cartridge.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rmc_get_geometry.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rmc_import.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rmc_mount.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rmc_read_elem_status.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rmc_seterrbuf.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/rwndtape.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/sacct.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/serrno.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/skiptape.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/usrlbl.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vdqm_Connect.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vdqm_DelDrive.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vdqm_DelVolumeReq.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vdqm_Disconnect.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vdqm_NextDrive.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vdqm_NextVol.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vdqm_SendVolReq.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vdqm_UnitStatus.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_deletedenmap.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_deletedgnmap.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_deletelibrary.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_deletemodel.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_deletepool.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_deletetape.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_deltag.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_enterdenmap.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_enterdgnmap.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_enterlibrary.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_entermodel.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_enterpool.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_entertape.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_gettag.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_gettape.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_listdenmap.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_listdgnmap.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_listlibrary.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_listmodel.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_listpool.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_listtape.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_modifylibrary.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_modifymodel.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_modifypool.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_modifytape.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_querylibrary.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_querymodel.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_querypool.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_querytape.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_reclaim.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_seterrbuf.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_settag.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_tpmounted.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/vmgr_updatetape.3castor
%attr(0644,root,bin) %doc /usr/share/man/man3/wrttpmrk.3castor
%attr(0644,root,bin) %doc /usr/share/man/man4/Castor_limits.4castor
%ifarch x86_64
%attr(0644,root,root) /usr/include/shift.h
%attr(0644,root,root) /usr/include/shift/Castor_limits.h
%attr(0644,root,root) /usr/include/shift/Cdlopen_api.h
%attr(0644,root,root) /usr/include/shift/Cgetopt.h
%attr(0644,root,root) /usr/include/shift/Cglobals.h
%attr(0644,root,root) /usr/include/shift/Cgrp.h
%attr(0644,root,root) /usr/include/shift/Cinit.h
%attr(0644,root,root) /usr/include/shift/Cmutex.h
%attr(0644,root,root) /usr/include/shift/Cnetdb.h
%attr(0644,root,root) /usr/include/shift/Cns.h
%attr(0644,root,root) /usr/include/shift/Cns_api.h
%attr(0644,root,root) /usr/include/shift/Cns_constants.h
%attr(0644,root,root) /usr/include/shift/Cns_server.h
%attr(0644,root,root) /usr/include/shift/Cns_struct.h
%attr(0644,root,root) /usr/include/shift/Cpool_api.h
%attr(0644,root,root) /usr/include/shift/Cpwd.h
%attr(0644,root,root) /usr/include/shift/Cregexp.h
%attr(0644,root,root) /usr/include/shift/Cregexp_magic.h
%attr(0644,root,root) /usr/include/shift/Csched_api.h
%attr(0644,root,root) /usr/include/shift/Csched_flags.h
%attr(0644,root,root) /usr/include/shift/Csec.h
%attr(0644,root,root) /usr/include/shift/Csec_api.h
%attr(0644,root,root) /usr/include/shift/Csec_common.h
%attr(0644,root,root) /usr/include/shift/Csec_constants.h
%attr(0644,root,root) /usr/include/shift/Csec_plugin.h
%attr(0644,root,root) /usr/include/shift/Csemaphore.h
%attr(0644,root,root) /usr/include/shift/Csetprocname.h
%attr(0644,root,root) /usr/include/shift/Csnprintf.h
%attr(0644,root,root) /usr/include/shift/Cstrerror.h
%attr(0644,root,root) /usr/include/shift/Ctape.h
%attr(0644,root,root) /usr/include/shift/Ctape_api.h
%attr(0644,root,root) /usr/include/shift/Ctape_constants.h
%attr(0644,root,root) /usr/include/shift/Cthread_api.h
%attr(0644,root,root) /usr/include/shift/Cthread_flags.h
%attr(0644,root,root) /usr/include/shift/Cthread_typedef.h
%attr(0644,root,root) /usr/include/shift/Cupv.h
%attr(0644,root,root) /usr/include/shift/Cupv_api.h
%attr(0644,root,root) /usr/include/shift/Cupv_constants.h
%attr(0644,root,root) /usr/include/shift/Cupv_server.h
%attr(0644,root,root) /usr/include/shift/Cupv_struct.h
%attr(0644,root,root) /usr/include/shift/Cupv_util.h
%attr(0644,root,root) /usr/include/shift/Cuuid.h
%attr(0644,root,root) /usr/include/shift/RfioTURL.h
%attr(0644,root,root) /usr/include/shift/common.h
%attr(0644,root,root) /usr/include/shift/dlf_api.h
%attr(0644,root,root) /usr/include/shift/dmc.h
%attr(0644,root,root) /usr/include/shift/expert.h
%attr(0644,root,root) /usr/include/shift/expert_api.h
%attr(0644,root,root) /usr/include/shift/expert_constants.h
%attr(0644,root,root) /usr/include/shift/expert_daemon.h
%attr(0644,root,root) /usr/include/shift/getacct.h
%attr(0644,root,root) /usr/include/shift/getacctent.h
%attr(0644,root,root) /usr/include/shift/getconfent.h
%attr(0644,root,root) /usr/include/shift/log.h
%attr(0644,root,root) /usr/include/shift/marshall.h
%attr(0644,root,root) /usr/include/shift/md5.h
%attr(0644,root,root) /usr/include/shift/net.h
%attr(0644,root,root) /usr/include/shift/osdep.h
%attr(0644,root,root) /usr/include/shift/patchlevel.h
%attr(0644,root,root) /usr/include/shift/rfcntl.h
%attr(0644,root,root) /usr/include/shift/rfio.h
%attr(0644,root,root) /usr/include/shift/rfio_api.h
%attr(0644,root,root) /usr/include/shift/rfio_constants.h
%attr(0644,root,root) /usr/include/shift/rfio_errno.h
%attr(0644,root,root) /usr/include/shift/rfio_lcastorfdt.h
%attr(0644,root,root) /usr/include/shift/rmc.h
%attr(0644,root,root) /usr/include/shift/rmc_api.h
%attr(0644,root,root) /usr/include/shift/rmc_constants.h
%attr(0644,root,root) /usr/include/shift/rmnode_util.h
%attr(0644,root,root) /usr/include/shift/rtcp.h
%attr(0644,root,root) /usr/include/shift/rtcp_api.h
%attr(0644,root,root) /usr/include/shift/rtcp_constants.h
%attr(0644,root,root) /usr/include/shift/rtcp_server.h
%attr(0644,root,root) /usr/include/shift/rtcpcld.h
%attr(0644,root,root) /usr/include/shift/rtcpcld_constants.h
%attr(0644,root,root) /usr/include/shift/rtcpcld_messages.h
%attr(0644,root,root) /usr/include/shift/rtcpcldapi.h
%attr(0644,root,root) /usr/include/shift/sacct.h
%attr(0644,root,root) /usr/include/shift/scsictl.h
%attr(0644,root,root) /usr/include/shift/serrno.h
%attr(0644,root,root) /usr/include/shift/smc.h
%attr(0644,root,root) /usr/include/shift/socket_timeout.h
%attr(0644,root,root) /usr/include/shift/stage_api.h
%attr(0644,root,root) /usr/include/shift/stage_constants.h
%attr(0644,root,root) /usr/include/shift/stage_limits.h
%attr(0644,root,root) /usr/include/shift/stager_api.h
%attr(0644,root,root) /usr/include/shift/stager_catalogInterface.h
%attr(0644,root,root) /usr/include/shift/stager_client_api.h
%attr(0644,root,root) /usr/include/shift/stager_constants.h
%attr(0644,root,root) /usr/include/shift/stager_errmsg.h
%attr(0644,root,root) /usr/include/shift/stager_extern_globals.h
%attr(0644,root,root) /usr/include/shift/stager_macros.h
%attr(0644,root,root) /usr/include/shift/stager_mapper.h
%attr(0644,root,root) /usr/include/shift/stager_messages.h
%attr(0644,root,root) /usr/include/shift/stager_mover_api.h
%attr(0644,root,root) /usr/include/shift/stager_util.h
%attr(0644,root,root) /usr/include/shift/stager_uuid.h
%attr(0644,root,root) /usr/include/shift/trace.h
%attr(0644,root,root) /usr/include/shift/u64subr.h
%attr(0644,root,root) /usr/include/shift/util.h
%attr(0644,root,root) /usr/include/shift/vdqm.h
%attr(0644,root,root) /usr/include/shift/vdqm_api.h
%attr(0644,root,root) /usr/include/shift/vdqm_constants.h
%attr(0644,root,root) /usr/include/shift/vmgr.h
%attr(0644,root,root) /usr/include/shift/vmgr_api.h
%attr(0644,root,root) /usr/include/shift/vmgr_constants.h
%attr(0644,root,root) /usr/include/shift/vmgr_server.h
%attr(0644,root,root) /usr/include/shift/vmgr_struct.h
%attr(0644,root,root) /usr/include/shift/ypgetacctent.h
%attr(-,root,root) /usr/lib64/libshift.so
%attr(-,root,root) /usr/lib64/libcastorcommon.so
%attr(-,root,root) /usr/lib64/libcastordlf.so
%attr(-,root,root) /usr/lib64/libcastorupv.so
%attr(-,root,root) /usr/lib64/libcastorns.so
%attr(-,root,root) /usr/lib64/libcastorsecurity.so
%attr(-,root,root) /usr/lib64/libcastortape.so
%attr(-,root,root) /usr/lib64/libcastorrfio.so
%attr(-,root,root) /usr/lib64/libcastorclient.so
%attr(-,root,root) /usr/lib64/libcastorvdqm.so
%attr(-,root,root) /usr/lib64/libcastorrtcopy.so
%attr(-,root,root) /usr/lib64/libcastorvmgr.so
%attr(-,root,root) /usr/lib64/libcastorexpert.so
%else
%attr(0644,root,root) /usr/include/shift.h
%attr(0644,root,root) /usr/include/shift/Castor_limits.h
%attr(0644,root,root) /usr/include/shift/Cdlopen_api.h
%attr(0644,root,root) /usr/include/shift/Cgetopt.h
%attr(0644,root,root) /usr/include/shift/Cglobals.h
%attr(0644,root,root) /usr/include/shift/Cgrp.h
%attr(0644,root,root) /usr/include/shift/Cinit.h
%attr(0644,root,root) /usr/include/shift/Cmutex.h
%attr(0644,root,root) /usr/include/shift/Cnetdb.h
%attr(0644,root,root) /usr/include/shift/Cns.h
%attr(0644,root,root) /usr/include/shift/Cns_api.h
%attr(0644,root,root) /usr/include/shift/Cns_constants.h
%attr(0644,root,root) /usr/include/shift/Cns_server.h
%attr(0644,root,root) /usr/include/shift/Cns_struct.h
%attr(0644,root,root) /usr/include/shift/Cpool_api.h
%attr(0644,root,root) /usr/include/shift/Cpwd.h
%attr(0644,root,root) /usr/include/shift/Cregexp.h
%attr(0644,root,root) /usr/include/shift/Cregexp_magic.h
%attr(0644,root,root) /usr/include/shift/Csched_api.h
%attr(0644,root,root) /usr/include/shift/Csched_flags.h
%attr(0644,root,root) /usr/include/shift/Csec.h
%attr(0644,root,root) /usr/include/shift/Csec_api.h
%attr(0644,root,root) /usr/include/shift/Csec_common.h
%attr(0644,root,root) /usr/include/shift/Csec_constants.h
%attr(0644,root,root) /usr/include/shift/Csec_plugin.h
%attr(0644,root,root) /usr/include/shift/Csemaphore.h
%attr(0644,root,root) /usr/include/shift/Csetprocname.h
%attr(0644,root,root) /usr/include/shift/Csnprintf.h
%attr(0644,root,root) /usr/include/shift/Cstrerror.h
%attr(0644,root,root) /usr/include/shift/Ctape.h
%attr(0644,root,root) /usr/include/shift/Ctape_api.h
%attr(0644,root,root) /usr/include/shift/Ctape_constants.h
%attr(0644,root,root) /usr/include/shift/Cthread_api.h
%attr(0644,root,root) /usr/include/shift/Cthread_flags.h
%attr(0644,root,root) /usr/include/shift/Cthread_typedef.h
%attr(0644,root,root) /usr/include/shift/Cupv.h
%attr(0644,root,root) /usr/include/shift/Cupv_api.h
%attr(0644,root,root) /usr/include/shift/Cupv_constants.h
%attr(0644,root,root) /usr/include/shift/Cupv_server.h
%attr(0644,root,root) /usr/include/shift/Cupv_struct.h
%attr(0644,root,root) /usr/include/shift/Cupv_util.h
%attr(0644,root,root) /usr/include/shift/Cuuid.h
%attr(0644,root,root) /usr/include/shift/RfioTURL.h
%attr(0644,root,root) /usr/include/shift/common.h
%attr(0644,root,root) /usr/include/shift/dlf_api.h
%attr(0644,root,root) /usr/include/shift/dmc.h
%attr(0644,root,root) /usr/include/shift/expert.h
%attr(0644,root,root) /usr/include/shift/expert_api.h
%attr(0644,root,root) /usr/include/shift/expert_constants.h
%attr(0644,root,root) /usr/include/shift/expert_daemon.h
%attr(0644,root,root) /usr/include/shift/getacct.h
%attr(0644,root,root) /usr/include/shift/getacctent.h
%attr(0644,root,root) /usr/include/shift/getconfent.h
%attr(0644,root,root) /usr/include/shift/log.h
%attr(0644,root,root) /usr/include/shift/marshall.h
%attr(0644,root,root) /usr/include/shift/md5.h
%attr(0644,root,root) /usr/include/shift/net.h
%attr(0644,root,root) /usr/include/shift/osdep.h
%attr(0644,root,root) /usr/include/shift/patchlevel.h
%attr(0644,root,root) /usr/include/shift/rfcntl.h
%attr(0644,root,root) /usr/include/shift/rfio.h
%attr(0644,root,root) /usr/include/shift/rfio_api.h
%attr(0644,root,root) /usr/include/shift/rfio_constants.h
%attr(0644,root,root) /usr/include/shift/rfio_errno.h
%attr(0644,root,root) /usr/include/shift/rfio_lcastorfdt.h
%attr(0644,root,root) /usr/include/shift/rmc.h
%attr(0644,root,root) /usr/include/shift/rmc_api.h
%attr(0644,root,root) /usr/include/shift/rmc_constants.h
%attr(0644,root,root) /usr/include/shift/rmnode_util.h
%attr(0644,root,root) /usr/include/shift/rtcp.h
%attr(0644,root,root) /usr/include/shift/rtcp_api.h
%attr(0644,root,root) /usr/include/shift/rtcp_constants.h
%attr(0644,root,root) /usr/include/shift/rtcp_server.h
%attr(0644,root,root) /usr/include/shift/rtcpcld.h
%attr(0644,root,root) /usr/include/shift/rtcpcld_constants.h
%attr(0644,root,root) /usr/include/shift/rtcpcld_messages.h
%attr(0644,root,root) /usr/include/shift/rtcpcldapi.h
%attr(0644,root,root) /usr/include/shift/sacct.h
%attr(0644,root,root) /usr/include/shift/scsictl.h
%attr(0644,root,root) /usr/include/shift/serrno.h
%attr(0644,root,root) /usr/include/shift/smc.h
%attr(0644,root,root) /usr/include/shift/socket_timeout.h
%attr(0644,root,root) /usr/include/shift/stage_api.h
%attr(0644,root,root) /usr/include/shift/stage_constants.h
%attr(0644,root,root) /usr/include/shift/stage_limits.h
%attr(0644,root,root) /usr/include/shift/stager_api.h
%attr(0644,root,root) /usr/include/shift/stager_catalogInterface.h
%attr(0644,root,root) /usr/include/shift/stager_client_api.h
%attr(0644,root,root) /usr/include/shift/stager_constants.h
%attr(0644,root,root) /usr/include/shift/stager_errmsg.h
%attr(0644,root,root) /usr/include/shift/stager_extern_globals.h
%attr(0644,root,root) /usr/include/shift/stager_macros.h
%attr(0644,root,root) /usr/include/shift/stager_mapper.h
%attr(0644,root,root) /usr/include/shift/stager_messages.h
%attr(0644,root,root) /usr/include/shift/stager_mover_api.h
%attr(0644,root,root) /usr/include/shift/stager_util.h
%attr(0644,root,root) /usr/include/shift/stager_uuid.h
%attr(0644,root,root) /usr/include/shift/trace.h
%attr(0644,root,root) /usr/include/shift/u64subr.h
%attr(0644,root,root) /usr/include/shift/util.h
%attr(0644,root,root) /usr/include/shift/vdqm.h
%attr(0644,root,root) /usr/include/shift/vdqm_api.h
%attr(0644,root,root) /usr/include/shift/vdqm_constants.h
%attr(0644,root,root) /usr/include/shift/vmgr.h
%attr(0644,root,root) /usr/include/shift/vmgr_api.h
%attr(0644,root,root) /usr/include/shift/vmgr_constants.h
%attr(0644,root,root) /usr/include/shift/vmgr_server.h
%attr(0644,root,root) /usr/include/shift/vmgr_struct.h
%attr(0644,root,root) /usr/include/shift/ypgetacctent.h
%attr(-,root,root) /usr/lib/libshift.so
%attr(-,root,root) /usr/lib/libcastorcommon.so
%attr(-,root,root) /usr/lib/libcastordlf.so
%attr(-,root,root) /usr/lib/libcastorupv.so
%attr(-,root,root) /usr/lib/libcastorns.so
%attr(-,root,root) /usr/lib/libcastorsecurity.so
%attr(-,root,root) /usr/lib/libcastortape.so
%attr(-,root,root) /usr/lib/libcastorrfio.so
%attr(-,root,root) /usr/lib/libcastorclient.so
%attr(-,root,root) /usr/lib/libcastorvdqm.so
%attr(-,root,root) /usr/lib/libcastorrtcopy.so
%attr(-,root,root) /usr/lib/libcastorvmgr.so
%attr(-,root,root) /usr/lib/libcastorexpert.so
%endif

%if ! %compiling_client
%package -n castor-devel-oracle
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib-oracle
%description -n castor-devel-oracle
castor (Cern Advanced STORage system) - Oracle API
%files -n castor-devel-oracle
%defattr(-,root,root)
%ifarch x86_64
%attr(-,root,root) /usr/lib64/libcastorcommonora.so
%else
%attr(-,root,root) /usr/lib/libcastorcommonora.so
%endif
%endif

%if ! %compiling_client
%package -n castor-expert-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate
%description -n castor-expert-server
castor (Cern Advanced STORage system) - Expert server, used to trigger policies
%files -n castor-expert-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/expert.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/expertd.1castor
%attr(-,root,bin) %dir /var/log/castor
%attr(0640,root,root) /etc/castor/EXPCONFIG.example
%attr(0755,root,root) /etc/init.d/expertd
%attr(0644,root,root) /etc/sysconfig/expertd.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-expert-server
%attr(0750,root,root) /usr/bin/expertd
%post -n castor-expert-server
/sbin/chkconfig --add expertd
/sbin/service expertd condrestart > /dev/null 2>&1 || :
%preun -n castor-expert-server
if [ "$1" = 0 ]; then
    /sbin/service expertd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del expertd
fi
%pre -n castor-expert-server
# Move old log files to /var/log/castor
if [ -d /var/spool/expert ]; then
    /bin/mkdir /var/log/castor 2>/dev/null
    for src in `ls /var/spool/expert/log.*.gz 2>/dev/null`; do
        dest=`basename $src | sed 's/log/expertd.log/'`
        /bin/mv $src /var/log/castor/$dest 2>/dev/null
    done
    /bin/mv /var/spool/expert/log /var/log/castor/expertd.log 2>/dev/null
    # Correct the selinux context of the new log files
    if [ -x /usr/bin/chcon ]; then
      /usr/bin/chcon -R --reference=/var/log/castor /var/log/castor > /dev/null 2>&1
    fi
    # Remove old log directory
    /bin/rm -rf /var/spool/expert 2>/dev/null || :
fi
%endif

%if ! %compiling_client
%package -n castor-gc-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate
%description -n castor-gc-server
castor (Cern Advanced STORage system) - Garbage collector, running on every worker node
%files -n castor-gc-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/gcd.8castor
%attr(-,root,bin) %dir /var/log/castor
%attr(0755,stage,st) %dir /var/spool/castor
%attr(0755,root,root) /etc/init.d/gcd
%attr(0644,root,root) /etc/sysconfig/gcd.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-gc-server
%attr(0750,root,root) /usr/bin/gcd
%post -n castor-gc-server
/sbin/chkconfig --add gcd
/sbin/service gcd condrestart > /dev/null 2>&1 || :
%preun -n castor-gc-server
if [ "$1" = 0 ]; then
    /sbin/service gcd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del gcd
fi
%pre -n castor-gc-server
if [ -f /etc/rc.d/init.d/gcDaemon ]; then
    /sbin/service gcDaemon stop > /dev/null 2>&1 || :
fi
# Move old log files to /var/log/castor
if [ -d /var/spool/gc ]; then
    /bin/mkdir /var/log/castor 2>/dev/null
    for src in `ls /var/spool/gc/log.*.gz 2>/dev/null`; do
        dest=`basename $src | sed 's/log/gcd.log/'`
        /bin/mv $src /var/log/castor/$dest 2>/dev/null
    done
    /bin/mv /var/spool/gc/log /var/log/castor/gcd.log 2>/dev/null
    # Correct the selinux context of the new log files
    if [ -x /usr/bin/chcon ]; then
      /usr/bin/chcon -R --reference=/var/log/castor /var/log/castor > /dev/null 2>&1
    fi
    # Remove old log directory
    /bin/rm -rf /var/spool/gc 2>/dev/null
    /bin/chmod 644 /var/log/castor/gcd.* 2>/dev/null
    /bin/chown root:root /var/log/castor/gcd* 2>/dev/null || :
fi
%endif

%if ! %compiling_client
%package -n castor-hsmtools
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: cx_Oracle
%description -n castor-hsmtools
castor (Cern Advanced STORage system) - HSM Administration tools e.g. reclaim
%files -n castor-hsmtools
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/reclaim.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/c2probe.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/adler32.1castor
%attr(0755,root,root) /usr/bin/reclaim
%attr(0755,root,root) /usr/bin/c2probe
%attr(0755,root,root) /usr/bin/rfcpupd
%attr(0755,root,root) /usr/bin/stager_actualget
%attr(0755,root,root) /usr/bin/stager_actualput
%attr(0755,root,root) /usr/bin/adler32
%attr(0750,root,root) /usr/bin/checkSharedMemory
%endif

%if ! %compiling_client
%package -n castor-dbtools
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-dbtools
castor (Cern Advanced STORage system) - DB Administration tools
%files -n castor-dbtools
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/cleanLostFiles.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/deleteFileClass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/deleteSvcClass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/diskServer_qry.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/draindiskserver.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/enterFileClass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/enterSvcClass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/listFileClass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/listSvcClass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/modifyFileClass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/modifySvcClass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/moveDiskServer.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/printFileClass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/printSvcClass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vdqmDBInit.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vdqmdeletepriority.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vdqmlistpriority.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vdqmlistrequest.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vdqmsetpriority.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/adminMultiInstance.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/deletePriority.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/enterPriority.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/listPriority.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/migrateNewCopy.1castor
%attr(0755,root,root) /usr/bin/cleanLostFiles
%attr(0755,root,root) /usr/bin/deleteFileClass
%attr(0755,root,root) /usr/bin/deleteSvcClass
%attr(0755,root,root) /usr/bin/diskServer_qry
%attr(0755,root,root) /usr/bin/draindiskserver
%attr(0755,root,root) /usr/bin/enterFileClass
%attr(0755,root,root) /usr/bin/enterSvcClass
%attr(0755,root,root) /usr/bin/listFileClass
%attr(0755,root,root) /usr/bin/listSvcClass
%attr(0755,root,root) /usr/bin/modifyFileClass
%attr(0755,root,root) /usr/bin/modifySvcClass
%attr(0755,root,root) /usr/bin/moveDiskServer
%attr(0755,root,root) /usr/bin/printFileClass
%attr(0755,root,root) /usr/bin/printSvcClass
%attr(0755,root,root) /usr/lib/perl/CASTOR/castor_tools.pm
%attr(0644,root,root) /%{_python_lib}/castor_tools.py
%attr(0755,root,root) /usr/bin/vdqmDBInit
%attr(0755,root,root) /usr/bin/vdqmdeletepriority
%attr(0755,root,root) /usr/bin/vdqmlistpriority
%attr(0755,root,root) /usr/bin/vdqmlistrequest
%attr(0755,root,root) /usr/bin/vdqmsetpriority
%attr(0755,root,root) /usr/bin/checkreplicas
%attr(0755,root,root) /usr/bin/deletePriority
%attr(0755,root,root) /usr/bin/enterPriority
%attr(0755,root,root) /usr/bin/listPriority
%attr(0755,root,root) /usr/bin/migrateNewCopy
%endif

%if ! %compiling_client
%package -n castor-job
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate
%description -n castor-job
castor (Cern Advanced STORage system) - The job giving user access to data on the worder nodes
%files -n castor-job
%defattr(-,root,root)
%attr(-,root,bin) %dir /var/log/castor
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-job
%attr(6755,stage,st) /usr/bin/stagerjob
%attr(6755,stage,st) /usr/bin/d2dtransfer
%pre -n castor-job
# Move old log files to /var/log/castor
if [ -d /var/spool/job ]; then
    /bin/mkdir /var/log/castor 2>/dev/null
    for src in `ls /var/spool/job/log.*.gz 2>/dev/null`; do
        dest=`basename $src | sed 's/log/stagerjob.log/'`
        /bin/mv $src /var/log/castor/$dest 2>/dev/null
    done
    /bin/mv /var/spool/job/log /var/log/castor/stagerjob.log 2>/dev/null

    for src in `ls /var/spool/job/diskcopy.*.gz 2>/dev/null`; do
        dest=`basename $src | sed 's/diskcopy/d2dtransfer.log/'`
        /bin/mv $src /var/log/castor/$dest 2>/dev/null
    done
    /bin/mv /var/spool/job/diskcopy /var/log/castor/d2dtransfer.log 2>/dev/null
    # Correct the selinux context of the new log files
    if [ -x /usr/bin/chcon ]; then
      /usr/bin/chcon -R --reference=/var/log/castor /var/log/castor > /dev/null 2>&1
    fi
    # Remove old log directory
    /bin/rm -rf /var/spool/job 2>/dev/null

    /bin/chmod 644 /var/log/castor/stagerjob.* 2>/dev/null
    /bin/chmod 644 /var/log/castor/d2dtransfer.* 2>/dev/null
    /bin/chown root:root /var/log/castor/stagerjob* 2>/dev/null
    /bin/chown root:root /var/log/castor/d2dtransfer* 2>/dev/null || :
fi
%endif

%if ! %compiling_client
%package -n castor-jobmanager-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate
%description -n castor-jobmanager-server
castor (Cern Advanced STORage system) - The Job Manager server used to submit jobs into the scheduler
%files -n castor-jobmanager-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/jobmanagerd.8castor
%attr(-,root,bin) %dir /var/log/castor
%attr(0755,stage,st) %dir /var/spool/castor
%attr(0755,root,root) /etc/init.d/jobmanagerd
%attr(0644,root,root) /etc/sysconfig/jobmanagerd.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-jobmanager-server
%attr(0750,root,root) /usr/bin/jobmanagerd
%post -n castor-jobmanager-server
/sbin/chkconfig --add jobmanagerd
/sbin/service jobmanagerd condrestart > /dev/null 2>&1 || :
%preun -n castor-jobmanager-server
if [ "$1" = 0 ]; then
    /sbin/service jobmanagerd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del jobmanagerd
fi
%pre -n castor-jobmanager-server
if [ -f /etc/rc.d/init.d/jobManager ]; then
    /sbin/service jobManager stop > /dev/null 2>&1 || :
fi
# Move old log files to /var/log/castor
if [ -d /var/spool/jobmanager ]; then
    /bin/mkdir /var/log/castor 2>/dev/null
    for src in `ls /var/spool/jobmanager/log.*.gz 2>/dev/null`; do
        dest=`basename $src | sed 's/log/jobmanagerd.log/'`
        /bin/mv $src /var/log/castor/$dest 2>/dev/null
    done
    /bin/mv /var/spool/jobmanager/log /var/log/castor/jobmanagerd.log 2>/dev/null
    /bin/chmod 644 /var/log/castor/jobmanagerd.* 2>/dev/null
    # Correct the selinux context of the new log files
    if [ -x /usr/bin/chcon ]; then
      /usr/bin/chcon -R --reference=/var/log/castor /var/log/castor > /dev/null 2>&1
    fi
    # Remove old log directory
    /bin/rm -rf /var/spool/jobmanager 2>/dev/null || :
fi
%endif

%package -n castor-lib
Summary: Cern Advanced mass STORage
Group: Application/Castor
Obsoletes: castor-sysconfig,castor-rtcopy-client,castor-lib-compat,castor-dlf-server,castor-doc,castor-commands,CASTOR-client,castor-stager-clientold,castor-rtcopy-messages
%description -n castor-lib
castor (Cern Advanced STORage system) - Static and shared libraries for end-users
%files -n castor-lib
%defattr(-,root,root)
%ifarch x86_64
%attr(-,root,root) /usr/lib64/libshift.so.2.1
%attr(-,root,root) /usr/lib64/libshift.so.2.1.9.8
%attr(-,root,root) /usr/lib64/libcastorcommon.so.2.1
%attr(-,root,root) /usr/lib64/libcastorcommon.so.2.1.9.8
%attr(-,root,root) /usr/lib64/libcastordlf.so.2.1
%attr(-,root,root) /usr/lib64/libcastordlf.so.2.1.9.8
%attr(-,root,root) /usr/lib64/libcastorupv.so.2.1
%attr(-,root,root) /usr/lib64/libcastorupv.so.2.1.9.8
%attr(-,root,root) /usr/lib64/libcastorns.so.2.1
%attr(-,root,root) /usr/lib64/libcastorns.so.2.1.9.8
%attr(-,root,root) /usr/lib64/libcastorsecurity.so.2.1
%attr(-,root,root) /usr/lib64/libcastorsecurity.so.2.1.9.8
%attr(-,root,root) /usr/lib64/libcastortape.so.2.1
%attr(-,root,root) /usr/lib64/libcastortape.so.2.1.9.8
%attr(-,root,root) /usr/lib64/libcastorrfio.so.2.1
%attr(-,root,root) /usr/lib64/libcastorrfio.so.2.1.9.8
%attr(-,root,root) /usr/lib64/libcastorclient.so.2.1
%attr(-,root,root) /usr/lib64/libcastorclient.so.2.1.9.8
%attr(-,root,root) /usr/lib64/libcastorvdqm.so.2.1
%attr(-,root,root) /usr/lib64/libcastorvdqm.so.2.1.9.8
%attr(-,root,root) /usr/lib64/libcastorrtcopy.so.2.1
%attr(-,root,root) /usr/lib64/libcastorrtcopy.so.2.1.9.8
%attr(-,root,root) /usr/lib64/libcastorvmgr.so.2.1
%attr(-,root,root) /usr/lib64/libcastorvmgr.so.2.1.9.8
%attr(-,root,root) /usr/lib64/libcastorexpert.so.2.1
%attr(-,root,root) /usr/lib64/libcastorexpert.so.2.1.9.8
%else
%attr(-,root,root) /usr/lib/libshift.so.2.1
%attr(-,root,root) /usr/lib/libshift.so.2.1.9.8
%attr(-,root,root) /usr/lib/libcastorcommon.so.2.1
%attr(-,root,root) /usr/lib/libcastorcommon.so.2.1.9.8
%attr(-,root,root) /usr/lib/libcastordlf.so.2.1
%attr(-,root,root) /usr/lib/libcastordlf.so.2.1.9.8
%attr(-,root,root) /usr/lib/libcastorupv.so.2.1
%attr(-,root,root) /usr/lib/libcastorupv.so.2.1.9.8
%attr(-,root,root) /usr/lib/libcastorns.so.2.1
%attr(-,root,root) /usr/lib/libcastorns.so.2.1.9.8
%attr(-,root,root) /usr/lib/libcastorsecurity.so.2.1
%attr(-,root,root) /usr/lib/libcastorsecurity.so.2.1.9.8
%attr(-,root,root) /usr/lib/libcastortape.so.2.1
%attr(-,root,root) /usr/lib/libcastortape.so.2.1.9.8
%attr(-,root,root) /usr/lib/libcastorrfio.so.2.1
%attr(-,root,root) /usr/lib/libcastorrfio.so.2.1.9.8
%attr(-,root,root) /usr/lib/libcastorclient.so.2.1
%attr(-,root,root) /usr/lib/libcastorclient.so.2.1.9.8
%attr(-,root,root) /usr/lib/libcastorvdqm.so.2.1
%attr(-,root,root) /usr/lib/libcastorvdqm.so.2.1.9.8
%attr(-,root,root) /usr/lib/libcastorrtcopy.so.2.1
%attr(-,root,root) /usr/lib/libcastorrtcopy.so.2.1.9.8
%attr(-,root,root) /usr/lib/libcastorvmgr.so.2.1
%attr(-,root,root) /usr/lib/libcastorvmgr.so.2.1.9.8
%attr(-,root,root) /usr/lib/libcastorexpert.so.2.1
%attr(-,root,root) /usr/lib/libcastorexpert.so.2.1.9.8
%endif
%post -n castor-lib
# IP tables modification to allow the castor client to open ports
if [ -e /etc/sysconfig/iptables ]; then
  if ! /bin/grep -q 'controlled by CASTOR-client RPM' /etc/sysconfig/iptables; then
    /bin/cat <<EOFiptable |\
/bin/sed -i.castor -e '/-A RH-Firewall-1-INPUT -m state --state ESTABLISHED,RELATED -j ACCEPT/r /dev/stdin' /etc/sysconfig/iptables
# controlled by CASTOR-client RPM 
# allow callbacks for RFIO, port range corresponds to default callback range
-A RH-Firewall-1-INPUT -m state --state NEW -m tcp -p tcp --dport 30000:30100 -j ACCEPT
# end of CASTOR-client RPM modifications
EOFiptable
    /sbin/service iptables condrestart > /dev/null 2>&1 || :
  fi
fi
# Call to ldconfig after we installed new libraries
/sbin/ldconfig
# Correct the selinux context of new log files
if [ -x /usr/bin/chcon ]; then
  /usr/bin/chcon -R --reference=/var/log/castor /var/log/castor > /dev/null 2>&1 || :
fi

%postun -n castor-lib
if [ "$1" = 0 ]; then
  # IP tables modification to allow the castor client to open ports
  if [ -e /etc/sysconfig/iptables ]; then
      /bin/sed -i.castor -e '/controlled by CASTOR-client RPM/,/end of CASTOR-client RPM modifications/d' /etc/sysconfig/iptables
      /sbin/service iptables condrestart > /dev/null 2>&1 || :
  fi
  # call to ldconfig after we uninstalled libraries
  /sbin/ldconfig
fi

%if ! %compiling_client
%package -n castor-lsf-plugin
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: python,logrotate
%description -n castor-lsf-plugin
castor (Cern Advanced STORage system) - Scheduler plugin for LSF (6.1 minimum) framework
%files -n castor-lsf-plugin
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/schmod_castor.1castor
%attr(-,root,bin) %dir /var/log/castor
%ifarch x86_64
%attr(0644,root,root) /usr/lib64/schmod_shmem.so
%attr(0644,root,root) /usr/lib64/schmod_python.so
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-lsf-plugin
%attr(0644,root,root) /etc/castor/policies/scheduler.py.example
%else
%attr(0644,root,root) /usr/lib/schmod_shmem.so
%attr(0644,root,root) /usr/lib/schmod_python.so
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-lsf-plugin
%attr(0644,root,root) /etc/castor/policies/scheduler.py.example
%endif
%pre -n castor-lsf-plugin
# Move old log files to /var/log/castor
if [ -d /var/spool/scheduler ]; then
    /bin/mkdir /var/log/castor 2>/dev/null
    for src in `ls /var/spool/scheduler/log.*.gz 2>/dev/null`; do
        dest=`basename $src | sed 's/log/schedulerd.log/'`
        /bin/mv $src /var/log/castor/$dest 2>/dev/null
    done
    /bin/mv /var/spool/scheduler/log /var/log/castor/schedulerd.log 2>/dev/null
    # Correct the selinux context of the new log files
    if [ -x /usr/bin/chcon ]; then
      /usr/bin/chcon -R --reference=/var/log/castor /var/log/castor > /dev/null 2>&1
    fi
    # Remove old log directory
    /bin/rm -rf /var/spool/scheduler 2>/dev/null
    /bin/chmod 644 /var/log/castor/schedulerd.* 2>/dev/null
    /bin/chown root:root /var/log/castor/schedulerd* 2>/dev/null || :
fi

%endif

%if ! %compiling_client
%package -n castor-lib-oracle
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-lib-oracle
castor (Cern Advanced STORage system) - Static and shared libraries for Oracle access
%files -n castor-lib-oracle
%defattr(-,root,root)
%ifarch x86_64
%attr(0640,root,root) /etc/castor/ORASTAGERCONFIG.example
%attr(-,root,root) /usr/lib64/libcastorcommonora.so.2.1
%attr(-,root,root) /usr/lib64/libcastorcommonora.so.2.1.9.8
%attr(-,root,root) /usr/lib64/libcastorcnvs.so.2.1
%attr(-,root,root) /usr/lib64/libcastorcnvs.so.2.1.9.8
%else
%attr(0640,root,root) /etc/castor/ORASTAGERCONFIG.example
%attr(-,root,root) /usr/lib/libcastorcommonora.so.2.1
%attr(-,root,root) /usr/lib/libcastorcommonora.so.2.1.9.8
%attr(-,root,root) /usr/lib/libcastorcnvs.so.2.1
%attr(-,root,root) /usr/lib/libcastorcnvs.so.2.1.9.8
%endif
%post -n castor-lib-oracle
# call to ldconfig after we installed new libraries
/sbin/ldconfig
%postun -n castor-lib-oracle
# call to ldconfig after we uninstalled libraries
/sbin/ldconfig
%endif

%package -n castor-ns-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-ns-client
castor (Cern Advanced STORage system) - Name server clients
%files -n castor-ns-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/nschclass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nschmod.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nschown.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsdelcomment.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsdeleteclass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsdelsegment.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsenterclass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsfind.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsgetacl.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsgetpath.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nslistclass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nslisttape.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsln.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsls.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsmkdir.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsmodifyclass.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsping.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsrename.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsrm.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsrmdir.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nsrmvid.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nssetacl.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nssetchecksum.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nssetcomment.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nssetfsize.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nssetsegment.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/nstouch.1castor
%attr(0755,root,root) /usr/bin/nschclass
%attr(0755,root,root) /usr/bin/nschmod
%attr(0755,root,root) /usr/bin/nschown
%attr(0755,root,root) /usr/bin/nsdelcomment
%attr(0755,root,root) /usr/bin/nsdeleteclass
%attr(0755,root,root) /usr/bin/nsdelsegment
%attr(0755,root,root) /usr/bin/nsenterclass
%attr(0755,root,root) /usr/bin/nsfind
%attr(0755,root,root) /usr/bin/nsgetacl
%attr(0755,root,root) /usr/bin/nsgetpath
%attr(0755,root,root) /usr/bin/nslistclass
%attr(0755,root,root) /usr/bin/nslisttape
%attr(0755,root,root) /usr/bin/nsln
%attr(0755,root,root) /usr/bin/nsls
%attr(0755,root,root) /usr/bin/nsmkdir
%attr(0755,root,root) /usr/bin/nsmodifyclass
%attr(0755,root,root) /usr/bin/nsping
%attr(0755,root,root) /usr/bin/nsrename
%attr(0755,root,root) /usr/bin/nsrm
%attr(0755,root,root) /usr/bin/nsrmdir
%attr(0755,root,root) /usr/bin/nsrmvid
%attr(0755,root,root) /usr/bin/nssetchecksum
%attr(0755,root,root) /usr/bin/nssetacl
%attr(0755,root,root) /usr/bin/nssetcomment
%attr(0755,root,root) /usr/bin/nssetfsize
%attr(0755,root,root) /usr/bin/nssetsegment
%attr(0755,root,root) /usr/bin/nstouch

%if ! %compiling_client
%package -n castor-ns-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,vdt_globus_essentials
%description -n castor-ns-server
castor (Cern Advanced STORage system) - Name server daemon
%files -n castor-ns-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/nsd.8castor
%attr(-,root,bin) %dir /var/log/castor
%attr(0640,root,root) /etc/castor/NSCONFIG.example
%attr(0755,root,root) /etc/init.d/nsd
%attr(0644,root,root) /etc/sysconfig/nsd.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-ns-server
%attr(0750,root,root) /usr/bin/nsd
%post -n castor-ns-server
/sbin/chkconfig --add nsd
/sbin/service nsd condrestart > /dev/null 2>&1 || :
%preun -n castor-ns-server
if [ "$1" = 0 ]; then
    /sbin/service nsd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del nsd
fi
%pre -n castor-ns-server
if [ -f /etc/rc.d/init.d/nsdaemon ]; then
    /sbin/service nsdaemon stop > /dev/null 2>&1 || :
fi
# Move old log files to /var/log/castor
if [ -d /var/spool/ns ]; then
    /bin/mkdir /var/log/castor 2>/dev/null
    for src in `ls /var/spool/ns/log.*.gz 2>/dev/null`; do
        dest=`basename $src | sed 's/log/nsd.log/'`
        /bin/mv $src /var/log/castor/$dest 2>/dev/null
    done
    /bin/mv /var/spool/ns/log /var/log/castor/nsd.log 2>/dev/null
    # Correct the selinux context of the new log files
    if [ -x /usr/bin/chcon ]; then
      /usr/bin/chcon -R --reference=/var/log/castor /var/log/castor > /dev/null 2>&1
    fi
    # Remove old log directory
    /bin/rm -rf /var/spool/ns 2>/dev/null || :
fi
%endif

%if ! %compiling_client
%package -n castor-policies
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: perl
%description -n castor-policies
castor (Cern Advanced STORage system) - Policies used by the expert system
%files -n castor-policies
%defattr(-,root,root)
%attr(0644,root,root) /etc/castor/expert/migrator.pl
%attr(0644,root,root) /etc/castor/expert/migratorRetryPolicy.pl
%attr(0644,root,root) /etc/castor/expert/recaller.pl
%attr(0644,root,root) /etc/castor/expert/recallerRetryPolicy.pl
%attr(0644,root,root) /etc/castor/expert/replica.pl
%endif

%package -n castor-rfio-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-rfio-client
castor (Cern Advanced STORage system) - RFIO clients
%files -n castor-rfio-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/rfcat.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/rfchmod.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/rfcp.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/rfdir.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/rfmkdir.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/rfrename.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/rfrm.1castor
%attr(0755,root,root) /usr/bin/rfcat
%attr(0755,root,root) /usr/bin/rfchmod
%attr(0755,root,root) /usr/bin/rfcp
%attr(0755,root,root) /usr/bin/rfdir
%attr(0755,root,root) /usr/bin/rfmkdir
%attr(0755,root,root) /usr/bin/rfrename
%attr(0755,root,root) /usr/bin/rfrm
%attr(0755,root,root) /usr/bin/rfstat

%if ! %compiling_client
%package -n castor-rfio-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,vdt_globus_essentials
%description -n castor-rfio-server
castor (Cern Advanced STORage system) - RFIO server
%files -n castor-rfio-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/rfiod.1castor
%attr(-,root,bin) %dir /var/log/castor
%attr(0755,root,root) /etc/init.d/rfiod
%attr(0644,root,root) /etc/sysconfig/rfiod.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-rfio-server
%attr(0755,root,root) /usr/bin/rfiod
%post -n castor-rfio-server
/sbin/chkconfig --add rfiod
/sbin/service rfiod condrestart > /dev/null 2>&1 || :
%preun -n castor-rfio-server
if [ "$1" = 0 ]; then
    /sbin/service rfiod stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del rfiod
fi
%pre -n castor-rfio-server
# Move old log files to /var/log/castor
if [ -d /var/spool/rfio ]; then
    /bin/mkdir /var/log/castor 2>/dev/null
    for src in `ls /var/spool/rfio/rfiod.*.gz 2>/dev/null`; do
        dest=`basename $src`
        /bin/mv $src /var/log/castor/$dest 2>/dev/null
    done
    /bin/mv /var/spool/rfio/rfiod.log /var/log/castor/rfiod.log 2>/dev/null
    # Correct the selinux context of the new log files
    if [ -x /usr/bin/chcon ]; then
      /usr/bin/chcon -R --reference=/var/log/castor /var/log/castor > /dev/null 2>&1
    fi
    # Remove old log directory
    /bin/rm -rf /var/spool/rfio 2>/dev/null || :
fi
%endif

%if ! %compiling_client
%package -n castor-rh-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,castor-lib-oracle,vdt_globus_essentials
%description -n castor-rh-server
castor (Cern Advanced STORage system) - Request Handler server
%files -n castor-rh-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/rhd.8castor
%attr(-,root,bin) %dir /var/log/castor
%attr(0755,stage,st) %dir /var/spool/castor
%attr(0755,root,root) /etc/init.d/rhd
%attr(0644,root,root) /etc/sysconfig/rhd.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-rh-server
%attr(0750,root,root) /usr/bin/rhd
%post -n castor-rh-server
/sbin/chkconfig --add rhd
/sbin/service rhd condrestart > /dev/null 2>&1 || :
%preun -n castor-rh-server
if [ "$1" = 0 ]; then
    /sbin/service rhd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del rhd
fi
%pre -n castor-rh-server
if [ -f /etc/rc.d/init.d/rhserver ]; then
    /sbin/service rhserver stop > /dev/null 2>&1 || :
fi
# Move old log files to /var/log/castor
if [ -d /var/spool/rhserver ]; then
    /bin/mkdir /var/log/castor 2>/dev/null
    for src in `ls /var/spool/rhserver/log.*.gz 2>/dev/null`; do
        dest=`basename $src | sed 's/log/rhd.log/'`
        /bin/mv $src /var/log/castor/$dest 2>/dev/null
    done
    /bin/mv /var/spool/rhserver/log /var/log/castor/rhd.log 2>/dev/null
    /bin/chmod 644 /var/log/castor/rhd.* 2>/dev/null
    # Correct the selinux context of the new log files
    if [ -x /usr/bin/chcon ]; then
      /usr/bin/chcon -R --reference=/var/log/castor /var/log/castor > /dev/null 2>&1
    fi
    # Remove old log directory
    /bin/rm -rf /var/spool/rhserver 2>/dev/null || :
fi
%endif

%if ! %compiling_client
%package -n castor-repack-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,castor-lib-oracle
%description -n castor-repack-server
castor (Cern Advanced STORage system) - Repack server
%files -n castor-repack-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/repackd.8castor
%attr(-,root,bin) %dir /var/log/castor
%attr(0640,root,root) /etc/castor/ORAREPACKCONFIG.example
%attr(0755,root,root) /etc/init.d/repackd
%attr(0644,root,root) /etc/sysconfig/repackd.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-repack-server
%attr(0750,root,root) /usr/bin/repackd
%post -n castor-repack-server
/sbin/chkconfig --add repackd
/sbin/service repackd condrestart > /dev/null 2>&1 || :
%preun -n castor-repack-server
if [ "$1" = 0 ]; then
    /sbin/service repackd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del repackd
fi
%pre -n castor-repack-server
if [ -f /etc/rc.d/init.d/repackserver ]; then
    /sbin/service repackserver stop > /dev/null 2>&1 || :
fi
# Move old log files to /var/log/castor
if [ -d /var/spool/repack ]; then
    /bin/mkdir /var/log/castor 2>/dev/null
    for src in `ls /var/spool/repack/log.*.gz 2>/dev/null`; do
        dest=`basename $src | sed 's/log/repackd.log/'`
        /bin/mv $src /var/log/castor/$dest 2>/dev/null
    done
    /bin/mv /var/spool/repack/log /var/log/castor/repackd.log 2>/dev/null
    /bin/chmod 644 /var/log/castor/repackd.* 2>/dev/null
    /bin/chown root:root /var/log/castor/repackd.* 2>/dev/null
    # Correct the selinux context of the new log files
    if [ -x /usr/bin/chcon ]; then
      /usr/bin/chcon -R --reference=/var/log/castor /var/log/castor > /dev/null 2>&1
    fi
    # Remove old log directory
    /bin/rm -rf /var/spool/repack 2>/dev/null || :
fi
%endif

%if ! %compiling_client
%package -n castor-repack-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-repack-client
castor (Cern Advanced STORage system) - Repack client
%files -n castor-repack-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/repack.1castor
%attr(0755,root,root) /usr/bin/repack
%endif

%if ! %compiling_client
%package -n castor-rmc-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate
%description -n castor-rmc-server
castor (Cern Advanced STORage system) - Remote Media Controller server
%files -n castor-rmc-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/rmcd.8castor
%attr(-,root,bin) %dir /var/log/castor
%attr(0755,root,root) /etc/init.d/rmcd
%attr(0644,root,root) /etc/sysconfig/rmcd.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-rmc-server
%attr(0750,root,root) /usr/bin/rmcd
%post -n castor-rmc-server
/sbin/chkconfig --add rmcd
/sbin/service rmcd condrestart > /dev/null 2>&1 || :
%preun -n castor-rmc-server
if [ "$1" = 0 ]; then
    /sbin/service rmcd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del rmcd
fi
%pre -n castor-rmc-server
if [ -f /etc/rc.d/init.d/rmcdaemon ]; then
    /sbin/service rmcdaemon stop > /dev/null 2>&1 || :
fi
# Move old log files to /var/log/castor
if [ -d /var/spool/rmc ]; then
    /bin/mkdir /var/log/castor 2>/dev/null
    for src in `ls /var/spool/rmc/log.*.gz 2>/dev/null`; do
        dest=`basename $src | sed 's/log/rmcd.log/'`
        /bin/mv $src /var/log/castor/$dest 2>/dev/null
    done
    /bin/mv /var/spool/rmc/log /var/log/castor/rmcd.log 2>/dev/null
    /bin/chmod 644 /var/log/castor/rmcd.* 2>/dev/null
    # Correct the selinux context of the new log files
    if [ -x /usr/bin/chcon ]; then
      /usr/bin/chcon -R --reference=/var/log/castor /var/log/castor > /dev/null 2>&1
    fi
    # Remove old log directory
    /bin/rm -rf /var/spool/rmc 2>/dev/null || :
fi
%endif

%if ! %compiling_client
%package -n castor-rmmaster-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib-monitor
%description -n castor-rmmaster-client
castor (Cern Advanced STORage system) - Resource Monitoring Master clients
%files -n castor-rmmaster-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/rmAdminNode.1castor
%attr(0755,root,root) /usr/bin/rmAdminNode
%endif

%if ! %compiling_client
%package -n castor-rmmaster-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,castor-lib-monitor
%description -n castor-rmmaster-server
castor (Cern Advanced STORage system) - Resource Monitoring Master server
%files -n castor-rmmaster-server
%defattr(-,root,root)
%attr(-,root,bin) %dir /var/log/castor
%attr(0755,stage,st) %dir /var/spool/castor
%attr(0755,root,root) /etc/init.d/rmmasterd
%attr(0644,root,root) /etc/sysconfig/rmmasterd.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-rmmaster-server
%attr(0750,root,root) /usr/bin/rmmasterd
%attr(0755,root,root) /usr/bin/rmGetNodes
%post -n castor-rmmaster-server
/sbin/chkconfig --add rmmasterd
/sbin/service rmmasterd condrestart > /dev/null 2>&1 || :
%preun -n castor-rmmaster-server
if [ "$1" = 0 ]; then
    /sbin/service rmmasterd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del rmmasterd
fi
%pre -n castor-rmmaster-server
if [ -f /etc/rc.d/init.d/rmMasterDaemon ]; then
    /sbin/service rmMasterDaemon stop > /dev/null 2>&1 || :
fi
# Move old log files to /var/log/castor
if [ -d /var/spool/rmmaster ]; then
    /bin/mkdir /var/log/castor 2>/dev/null
    for src in `ls /var/spool/rmmaster/log.*.gz 2>/dev/null`; do
        dest=`basename $src | sed 's/log/rmmasterd.log/'`
        /bin/mv $src /var/log/castor/$dest 2>/dev/null
    done
    /bin/mv /var/spool/rmmaster/log /var/log/castor/rmmasterd.log 2>/dev/null
    /bin/chmod 644 /var/log/castor/rmmasterd.* 2>/dev/null
    # Correct the selinux context of the new log files
    if [ -x /usr/bin/chcon ]; then
      /usr/bin/chcon -R --reference=/var/log/castor /var/log/castor > /dev/null 2>&1
    fi
    # Remove old log directory
    /bin/rm -rf /var/spool/rmmaster 2>/dev/null || :
fi
%endif

%if ! %compiling_client
%package -n castor-rmnode-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,castor-lib-monitor
%description -n castor-rmnode-server
castor (Cern Advanced STORage system) - Resource Monitoring running on each worker node
%files -n castor-rmnode-server
%defattr(-,root,root)
%attr(-,root,bin) %dir /var/log/castor
%attr(0755,stage,st) %dir /var/spool/castor
%attr(0755,root,root) /etc/init.d/rmnoded
%attr(0644,root,root) /etc/sysconfig/rmnoded.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-rmnode-server
%attr(0750,root,root) /usr/bin/rmnoded
%post -n castor-rmnode-server
/sbin/chkconfig --add rmnoded
/sbin/service rmnoded condrestart > /dev/null 2>&1 || :
%preun -n castor-rmnode-server
if [ "$1" = 0 ]; then
    /sbin/service rmnoded stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del rmnoded
fi
%pre -n castor-rmnode-server
if [ -f /etc/rc.d/init.d/rmNodeDaemon ]; then
    /sbin/service rmNodeDaemon stop > /dev/null 2>&1 || :
fi
# Move old log files to /var/log/castor
if [ -d /var/spool/rmnode ]; then
    /bin/mkdir /var/log/castor 2>/dev/null
    for src in `ls /var/spool/rmnode/log.*.gz 2>/dev/null`; do
        dest=`basename $src | sed 's/log/rmnoded.log/'`
        /bin/mv $src /var/log/castor/$dest 2>/dev/null
    done
    /bin/mv /var/spool/rmnode/log /var/log/castor/rmnoded.log 2>/dev/null
    /bin/chmod 644 /var/log/castor/rmnoded.* 2>/dev/null
    # Correct the selinux context of the new log files
    if [ -x /usr/bin/chcon ]; then
      /usr/bin/chcon -R --reference=/var/log/castor /var/log/castor > /dev/null 2>&1
    fi
    # Remove old log directory
    /bin/rm -rf /var/spool/rmnode 2>/dev/null || :
fi
%endif

%if ! %compiling_client
%package -n castor-rtcopy-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate
%description -n castor-rtcopy-server
castor (Cern Advanced STORage system) - Remote Tape Copy server running on a tape server
%files -n castor-rtcopy-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/killjid.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/rtcpd.1castor
%attr(-,root,bin) %dir /var/log/castor
%attr(-,root,bin) %dir /var/lib/castor
%attr(0755,root,root) /etc/init.d/rtcpd
%attr(0644,root,root) /etc/sysconfig/rtcpd.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-rtcopy-server
%attr(0750,root,root) /usr/bin/killjid
%attr(0750,root,root) /usr/bin/rtcpd
%post -n castor-rtcopy-server
/sbin/chkconfig --add rtcpd
/sbin/service rtcpd condrestart > /dev/null 2>&1 || :
%preun -n castor-rtcopy-server
if [ "$1" = 0 ]; then
    /sbin/service rtcpd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del rtcpd
fi
%pre -n castor-rtcopy-server
# Move old log files to /var/log/castor
if [ -d /var/spool/rtcopy ]; then
    /bin/mkdir /var/log/castor 2>/dev/null
    for src in `ls /var/spool/rtcopy/rtcopyd.*.gz 2>/dev/null`; do
        dest=`basename $src | sed 's/rtcopyd/rtcpd/'`
        /bin/mv $src /var/log/castor/$dest 2>/dev/null
    done
    /bin/mv /var/spool/rtcopy/rtcopyd.log /var/log/castor/rtcpd.log 2>/dev/null
    /bin/chmod 644 /var/log/castor/rtcpd.* 2>/dev/null
    # Correct the selinux context of the new log files
    if [ -x /usr/bin/chcon ]; then
      /usr/bin/chcon -R --reference=/var/log/castor /var/log/castor > /dev/null 2>&1
    fi
    # Remove old log directory
    /bin/rm -rf /var/spool/rtcopy 2>/dev/null || :
fi
%endif

%if ! %compiling_client
%package -n castor-rtcopy-clientserver
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,castor-lib-oracle
%description -n castor-rtcopy-clientserver
castor (Cern Advanced STORage system) - Remote Tape Copy Client Server running on top of a database. - This will generate raw RTCOPY commands understood by the rtcopy-server - running on tape server.
%files -n castor-rtcopy-clientserver
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/rtcpclientd.1castor
%attr(-,root,bin) %dir /var/log/castor
%attr(0755,root,root) /etc/init.d/rtcpclientd
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-rtcopy-clientserver
%attr(0755,root,root) /usr/bin/tperrhandler
%attr(0755,root,root) /usr/bin/migrator
%attr(0755,root,root) /usr/bin/recaller
%attr(0750,root,root) /usr/bin/rtcpclientd
%post -n castor-rtcopy-clientserver
/sbin/chkconfig --add rtcpclientd
/sbin/service rtcpclientd condrestart > /dev/null 2>&1 || :
%preun -n castor-rtcopy-clientserver
if [ "$1" = 0 ]; then
    /sbin/service rtcpclientd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del rtcpclientd
fi
%pre -n castor-rtcopy-clientserver
# Move old log files to /var/log/castor
if [ -d /var/spool/rtcpclientd ]; then
    /bin/mkdir /var/log/castor 2>/dev/null
    for src in `ls /var/spool/rtcpclientd/rtcpcld.*.gz 2>/dev/null`; do
        dest=`basename $src | sed 's/rtcpcld/rtcpclientd.log/'`
        /bin/mv $src /var/log/castor/$dest 2>/dev/null
    done
    /bin/mv /var/spool/rtcpclientd/rtcpcld /var/log/castor/rtcpclientd.log 2>/dev/null

    /bin/mv /var/spool/rtcpclientd/migrator.*.gz /var/log/castor/ 2>/dev/null
    /bin/mv /var/spool/rtcpclientd/migrator /var/log/castor/migrator.log 2>/dev/null

    /bin/mv /var/spool/rtcpclientd/recaller.*.gz /var/log/castor/ 2>/dev/null
    /bin/mv /var/spool/rtcpclientd/recaller /var/log/castor/recaller.log 2>/dev/null

    for src in `ls /var/spool/rtcpclientd/TapeErrorHandler.*.gz 2>/dev/null`; do
        dest=`basename $src | sed 's/TapeErrorHandler/tperrhandler.log/'`
        /bin/mv $src /var/log/castor/$dest 2>/dev/null
    done
    /bin/mv /var/spool/rtcpclientd/TapeErrorHandler /var/log/castor/tperrhandler.log 2>/dev/null

    # Correct the selinux context of the new log files
    if [ -x /usr/bin/chcon ]; then
      /usr/bin/chcon -R --reference=/var/log/castor /var/log/castor > /dev/null 2>&1
    fi
    # Remove old log directory
    /bin/rm -rf /var/spool/rtcpclientd 2>/dev/null

    /bin/chmod 644 /var/log/castor/rtcpclientd.* 2>/dev/null
    /bin/chmod 644 /var/log/castor/migrator.* 2>/dev/null
    /bin/chmod 644 /var/log/castor/recaller.* 2>/dev/null
    /bin/chmod 644 /var/log/castor/tperrhandler.* 2>/dev/null
    /bin/chown root:root /var/log/castor/rtcpclientd* 2>/dev/null
    /bin/chown root:root /var/log/castor/migrator* 2>/dev/null
    /bin/chown root:root /var/log/castor/recaller* 2>/dev/null
    /bin/chown root:root /var/log/castor/tperrhandler* 2>/dev/null || :
fi
%endif

%package -n castor-stager-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-stager-client
castor (Cern Advanced STORage system) - Stager clients
%files -n castor-stager-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_get.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_update.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_put.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_putdone.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_qry.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_rm.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_setfilegcweight.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_addprivilege.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_removeprivilege.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/stager_listprivileges.1castor
%attr(0755,root,root) /usr/bin/stager_get
%attr(0755,root,root) /usr/bin/stager_update
%attr(0755,root,root) /usr/bin/stager_put
%attr(0755,root,root) /usr/bin/stager_putdone
%attr(0755,root,root) /usr/bin/stager_qry
%attr(0755,root,root) /usr/bin/stager_rm
%attr(0755,root,root) /usr/bin/stager_setfilegcweight
%attr(0755,root,root) /usr/bin/stager_addprivilege
%attr(0755,root,root) /usr/bin/stager_removeprivilege
%attr(0755,root,root) /usr/bin/stager_listprivileges
%attr(0755,root,root) /usr/bin/castor

%if ! %compiling_client
%package -n castor-stager-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,castor-lib-oracle
%description -n castor-stager-server
castor (Cern Advanced STORage system) - Stager server
%files -n castor-stager-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/stagerd.8castor
%attr(-,root,bin) %dir /var/log/castor
%attr(0755,stage,st) %dir /var/spool/castor
%attr(0755,root,root) /etc/init.d/stagerd
%attr(0644,root,root) /etc/sysconfig/stagerd.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-stager-server
%attr(0750,root,root) /usr/bin/stagerd
%post -n castor-stager-server
/sbin/chkconfig --add stagerd
/sbin/service stagerd condrestart > /dev/null 2>&1 || :
%preun -n castor-stager-server
if [ "$1" = 0 ]; then
    /sbin/service stagerd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del stagerd
fi
%pre -n castor-stager-server
if [ -f /etc/rc.d/init.d/stager ]; then
    /sbin/service stager stop > /dev/null 2>&1 || :
fi
# Move old log files to /var/log/castor
if [ -d /var/spool/stager ]; then
    /bin/mkdir /var/log/castor 2>/dev/null
    for src in `ls /var/spool/stager/log.*.gz 2>/dev/null`; do
        dest=`basename $src | sed 's/log/stagerd.log/'`
        /bin/mv $src /var/log/castor/$dest 2>/dev/null
    done
    /bin/mv /var/spool/stager/log /var/log/castor/stagerd.log 2>/dev/null
    /bin/chmod 644 /var/log/castor/stagerd.* 2>/dev/null
    # Correct the selinux context of the new log files
    if [ -x /usr/bin/chcon ]; then
      /usr/bin/chcon -R --reference=/var/log/castor /var/log/castor > /dev/null 2>&1
    fi
    # Remove old log directory
    /bin/rm -rf /var/spool/stager 2>/dev/null || :
fi
%endif

%package -n castor-tape-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-tape-client
castor (Cern Advanced STORage system) - Tape clients
%files -n castor-tape-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/tpread.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/tprstat.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/tpstat.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/tpwrite.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/tpconfig.1castor
%attr(0755,root,root) /usr/bin/tpconfig
%attr(0755,root,root) /usr/bin/tpread
%attr(0755,root,root) /usr/bin/tprstat
%attr(0755,root,root) /usr/bin/tpstat
%attr(0755,root,root) /usr/bin/tpwrite

%if ! %compiling_client
%package -n castor-tape-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate
%description -n castor-tape-server
castor (Cern Advanced STORage system) - Tape server
%files -n castor-tape-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/smc.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/tape_oper.1castor
%attr(0644,root,bin) %doc /usr/share/man/man8/taped.8castor
%attr(0644,root,bin) %doc /usr/share/man/man1/tplabel.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/tpdump.1castor
%attr(-,root,bin) %dir /var/log/castor
%attr(0640,root,root) /etc/castor/TPCONFIG.example
%attr(0755,root,root) /etc/init.d/taped
%attr(0644,root,root) /etc/sysconfig/taped.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-tape-server
%attr(0750,root,root) /usr/bin/confdrive
%attr(0750,root,root) /usr/bin/mounttape
%attr(0750,root,root) /usr/bin/posovl
%attr(0750,root,root) /usr/bin/rlstape
%attr(6755,root,root) /usr/bin/smc
%attr(0750,root,root) /usr/bin/taped
%attr(0755,root,root) /usr/bin/tpdump
%attr(0755,root,root) /usr/bin/tplabel
%post -n castor-tape-server
/sbin/chkconfig --add taped
/sbin/service taped condrestart > /dev/null 2>&1 || :
%preun -n castor-tape-server
if [ "$1" = 0 ]; then
    /sbin/service taped stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del taped
fi
%pre -n castor-tape-server
if [ -f /etc/rc.d/init.d/tpdaemon ]; then
    /sbin/service tpdaemon stop > /dev/null 2>&1 || :
fi
# Move old log files to /var/log/castor
if [ -d /var/spool/tape ]; then
    /bin/mkdir /var/log/castor 2>/dev/null
    for src in `ls /var/spool/tape/log.*.gz 2>/dev/null`; do
        dest=`basename $src | sed 's/log/taped.log/'`
        /bin/mv $src /var/log/castor/$dest 2>/dev/null
    done
    /bin/mv /var/spool/tape/log /var/log/castor/taped.log 2>/dev/null
    /bin/chmod 644 /var/log/castor/taped.* 2>/dev/null
    # Correct the selinux context of the new log files
    if [ -x /usr/bin/chcon ]; then
      /usr/bin/chcon -R --reference=/var/log/castor /var/log/castor > /dev/null 2>&1
    fi
    # Remove old log directory
    /bin/rm -rf /var/spool/tape 2>/dev/null || :
fi
%endif

%package -n castor-upv-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-upv-client
castor (Cern Advanced STORage system) - User Privilege clients
%files -n castor-upv-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/Cupvadd.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/Cupvcheck.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/Cupvdelete.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/Cupvlist.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/Cupvmodify.1castor
%attr(0755,root,root) /usr/bin/Cupvadd
%attr(0755,root,root) /usr/bin/Cupvcheck
%attr(0755,root,root) /usr/bin/Cupvdelete
%attr(0755,root,root) /usr/bin/Cupvlist
%attr(0755,root,root) /usr/bin/Cupvmodify

%if ! %compiling_client
%package -n castor-upv-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate
%description -n castor-upv-server
castor (Cern Advanced STORage system) - User Privilege server
%files -n castor-upv-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/cupvd.8castor
%attr(-,root,bin) %dir /var/log/castor
%attr(0640,root,root) /etc/castor/CUPVCONFIG.example
%attr(0755,root,root) /etc/init.d/cupvd
%attr(0644,root,root) /etc/sysconfig/cupvd.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-upv-server
%attr(0750,root,root) /usr/bin/cupvd
%post -n castor-upv-server
/sbin/chkconfig --add cupvd
/sbin/service cupvd condrestart > /dev/null 2>&1 || :
%preun -n castor-upv-server
if [ "$1" = 0 ]; then
    /sbin/service cupvd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del cupvd
fi
%pre -n castor-upv-server
if [ -f /etc/rc.d/init.d/Cupvdaemon ]; then
    /sbin/service Cupvdaemon stop > /dev/null 2>&1 || :
fi
# Move old log files to /var/log/castor
if [ -d /var/spool/upv ]; then
    /bin/mkdir /var/log/castor 2>/dev/null
    for src in `ls /var/spool/upv/log.*.gz 2>/dev/null`; do
        dest=`basename $src | sed 's/log/cupvd.log/'`
        /bin/mv $src /var/log/castor/$dest 2>/dev/null
    done
    /bin/mv /var/spool/upv/log /var/log/castor/cupvd.log 2>/dev/null
    # Correct the selinux context of the new log files
    if [ -x /usr/bin/chcon ]; then
      /usr/bin/chcon -R --reference=/var/log/castor /var/log/castor > /dev/null 2>&1
    fi
    # Remove old log directory
    /bin/rm -rf /var/spool/upv 2>/dev/null || :
fi
%endif

%package -n castor-vdqm2-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
Obsoletes: castor-vdqm-client
%description -n castor-vdqm2-client
castor (Cern Advanced STORage system) - Volume Drive and Queue Manager clients version 2
%files -n castor-vdqm2-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/vdqm_admin.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/showqueues.1castor
%attr(0755,root,root) /usr/bin/showqueues
%attr(0755,root,root) /usr/bin/vdqm_admin

%if ! %compiling_client
%package -n castor-vdqm2-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,castor-lib-oracle,castor-vdqm2-lib-oracle
Obsoletes: castor-vdqm-server
%description -n castor-vdqm2-server
castor (Cern Advanced STORage system) - Volume Drive and Queue Manager server version 2
%files -n castor-vdqm2-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/vdqmd.8castor
%attr(-,root,bin) %dir /var/log/castor
%attr(0755,root,root) /etc/init.d/vdqmd
%attr(0644,root,root) /etc/sysconfig/vdqmd.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-vdqm2-server
%attr(0750,root,root) /usr/bin/vdqmd
%attr(0640,root,root) /etc/castor/ORAVDQMCONFIG.example
%post -n castor-vdqm2-server
/sbin/chkconfig --add vdqmd
/sbin/service vdqmd condrestart > /dev/null 2>&1 || :
%preun -n castor-vdqm2-server
if [ "$1" = 0 ]; then
    /sbin/service vdqmd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del vdqmd
fi
%pre -n castor-vdqm2-server
if [ -f /etc/rc.d/init.d/vdqmserver ]; then
    /sbin/service vdqmserver stop > /dev/null 2>&1 || :
fi
# Move old log files to /var/log/castor
if [ -d /var/spool/vdqm ]; then
    /bin/mkdir /var/log/castor 2>/dev/null
    for src in `ls /var/spool/vdqm/log.*.gz 2>/dev/null`; do
        dest=`basename $src | sed 's/log/vdqmd.log/'`
        /bin/mv $src /var/log/castor/$dest 2>/dev/null
    done
    /bin/mv /var/spool/vdqm/log /var/log/castor/vdqmd.log 2>/dev/null
    /bin/chmod 644 /var/log/castor/vdqm.* 2>/dev/null
    # Correct the selinux context of the new log files
    if [ -x /usr/bin/chcon ]; then
      /usr/bin/chcon -R --reference=/var/log/castor /var/log/castor > /dev/null 2>&1
    fi
    # Remove old log directory
    /bin/rm -rf /var/spool/vdqm 2>/dev/null || :
fi
%endif

%if ! %compiling_client
%package -n castor-vdqm2-lib-oracle
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate
%description -n castor-vdqm2-lib-oracle
castor (Cern Advanced STORage system) - Volume Drive and Queue Manager server version 2 library
%files -n castor-vdqm2-lib-oracle
%defattr(-,root,root)
%ifarch x86_64
%attr(-,root,root) /usr/lib64/libcastorvdqmora.so.2.1
%attr(-,root,root) /usr/lib64/libcastorvdqmora.so.2.1.9.8
%else
%attr(-,root,root) /usr/lib/libcastorvdqmora.so.2.1
%attr(-,root,root) /usr/lib/libcastorvdqmora.so.2.1.9.8
%endif
%endif

%package -n castor-vmgr-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-vmgr-client
castor (Cern Advanced STORage system) - Volume Manager clients
%files -n castor-vmgr-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgr.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrdeletedenmap.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrdeletedgnmap.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrdeletelibrary.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrdeletemodel.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrdeletepool.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrdeletetape.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrdeltag.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrenterdenmap.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrenterdgnmap.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrenterlibrary.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrentermodel.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrenterpool.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrentertape.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrgettag.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrlistdenmap.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrlistdgnmap.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrlistlibrary.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrlistmodel.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrlistpool.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrlisttape.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrmodifylibrary.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrmodifypool.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrmodifytape.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/vmgrsettag.1castor
%attr(0755,root,root) /usr/bin/vmgrdeletedenmap
%attr(0755,root,root) /usr/bin/vmgrdeletedgnmap
%attr(0755,root,root) /usr/bin/vmgrdeletelibrary
%attr(0755,root,root) /usr/bin/vmgrdeletemodel
%attr(0755,root,root) /usr/bin/vmgrdeletepool
%attr(0755,root,root) /usr/bin/vmgrdeletetape
%attr(0755,root,root) /usr/bin/vmgrdeltag
%attr(0755,root,root) /usr/bin/vmgrenterdenmap
%attr(0755,root,root) /usr/bin/vmgrenterdgnmap
%attr(0755,root,root) /usr/bin/vmgrenterlibrary
%attr(0755,root,root) /usr/bin/vmgrentermodel
%attr(0755,root,root) /usr/bin/vmgrenterpool
%attr(0755,root,root) /usr/bin/vmgrentertape
%attr(0755,root,root) /usr/bin/vmgrgettag
%attr(0755,root,root) /usr/bin/vmgrlistdenmap
%attr(0755,root,root) /usr/bin/vmgrlistdgnmap
%attr(0755,root,root) /usr/bin/vmgrlistlibrary
%attr(0755,root,root) /usr/bin/vmgrlistmodel
%attr(0755,root,root) /usr/bin/vmgrlistpool
%attr(0755,root,root) /usr/bin/vmgrlisttape
%attr(0755,root,root) /usr/bin/vmgrmodifylibrary
%attr(0755,root,root) /usr/bin/vmgrmodifypool
%attr(0755,root,root) /usr/bin/vmgrmodifytape
%attr(0755,root,root) /usr/bin/vmgrsettag

%if ! %compiling_client
%package -n castor-vmgr-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate
%description -n castor-vmgr-server
castor (Cern Advanced STORage system) - Volume Manager server
%files -n castor-vmgr-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/vmgrd.8castor
%attr(-,root,bin) %dir /var/log/castor
%attr(0640,root,root) /etc/castor/VMGRCONFIG.example
%attr(0755,root,root) /etc/init.d/vmgrd
%attr(0644,root,root) /etc/sysconfig/vmgrd.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-vmgr-server
%attr(0750,root,root) /usr/bin/vmgrd
%post -n castor-vmgr-server
/sbin/chkconfig --add vmgrd
/sbin/service vmgrd condrestart > /dev/null 2>&1 || :
%preun -n castor-vmgr-server
if [ "$1" = 0 ]; then
    /sbin/service vmgrd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del vmgrd
fi
%pre -n castor-vmgr-server
if [ -f /etc/rc.d/init.d/vmgrdaemon ]; then
    /sbin/service vmgrdaemon stop > /dev/null 2>&1 || :
fi
# Move old log files to /var/log/castor
if [ -d /var/spool/vmgr ]; then
    /bin/mkdir /var/log/castor 2>/dev/null
    for src in `ls /var/spool/vmgr/log.*.gz 2>/dev/null`; do
        dest=`basename $src | sed 's/log/vmgrd.log/'`
        /bin/mv $src /var/log/castor/$dest 2>/dev/null
    done
    /bin/mv /var/spool/vmgr/log /var/log/castor/vmgrd.log 2>/dev/null
    /bin/chmod 644 /var/log/castor/vmgr.* 2>/dev/null
    # Correct the selinux context of the new log files
    if [ -x /usr/bin/chcon ]; then
      /usr/bin/chcon -R --reference=/var/log/castor /var/log/castor > /dev/null 2>&1
    fi
    # Remove old log directory
    /bin/rm -rf /var/spool/vmgr 2>/dev/null || :
fi
%endif

%if ! %compiling_client
%package -n castor-dlf-web
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: php-oci8
%description -n castor-dlf-web
castor (Cern Advanced STORage system) - Distributed Logging Facility Web Interface
%files -n castor-dlf-web
%defattr(-,root,root)
%attr(-,root,bin) %dir /var/www/html/dlf
%attr(-,root,bin) %dir /var/www/html/dlf/db
%attr(-,root,bin) %dir /var/www/html/dlf/images
%attr(-,root,bin) %dir /var/www/html/dlf/js
%attr(0644,root,root) /var/www/html/dlf/config.php
%attr(0644,root,root) /var/www/html/dlf/dbview.php
%attr(0644,root,root) /var/www/html/dlf/index.php
%attr(0640,root,apache) /var/www/conf/dlf/login.conf.example
%attr(0644,root,root) /var/www/html/dlf/query.php
%attr(0644,root,root) /var/www/html/dlf/results.php
%attr(0644,root,root) /var/www/html/dlf/site.css
%attr(0644,root,root) /var/www/html/dlf/utils.php
%attr(0644,root,root) /var/www/html/dlf/db/oracle.php
%attr(0644,root,root) /var/www/html/dlf/js/CalendarPopup.js
%attr(0644,root,root) /var/www/html/dlf/js/Date.js
%attr(0644,root,root) /var/www/html/dlf/images/backdrop.png
%attr(0644,root,root) /var/www/html/dlf/images/css.png
%attr(0644,root,root) /var/www/html/dlf/images/php.png
%attr(0644,root,root) /var/www/html/dlf/images/xhtml.png
%endif

%if ! %compiling_client
%package -n castor-lib-monitor
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib
%description -n castor-lib-monitor
castor (Cern Advanced STORage system) - Shared libraries for monitoring framework
%files -n castor-lib-monitor
%defattr(-,root,root)
%ifarch x86_64
%attr(-,root,root) /usr/lib64/libcastormonitor.so.2.1
%attr(-,root,root) /usr/lib64/libcastormonitor.so.2.1.9.8
%else
%attr(-,root,root) /usr/lib/libcastormonitor.so.2.1
%attr(-,root,root) /usr/lib/libcastormonitor.so.2.1.9.8
%endif
%post -n castor-lib-monitor
# call to ldconfig after we installed new libraries
/sbin/ldconfig
%postun -n castor-lib-monitor
# call to ldconfig after we uninstalled libraries
/sbin/ldconfig
%endif

%if ! %compiling_client
%package -n castor-lib-tape
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib
Obsoletes: castor-lib-policy,castor-lib-tapeutils
%description -n castor-lib-tape
castor (Cern Advanced STORage system) - Shared utilities library for castor tape servers and command-line tools
%files -n castor-lib-tape
%defattr(-,root,root)
%ifarch x86_64
%attr(-,root,root) /usr/lib64/libcastortapegatewayprotocol.so.2.1
%attr(-,root,root) /usr/lib64/libcastortapegatewayprotocol.so.2.1.9.8
%attr(-,root,root) /usr/lib64/libcastortapepython.so.2.1
%attr(-,root,root) /usr/lib64/libcastortapepython.so.2.1.9.8
%attr(-,root,root) /usr/lib64/libcastortapeutils.so.2.1
%attr(-,root,root) /usr/lib64/libcastortapeutils.so.2.1.9.8
%else
%attr(-,root,root) /usr/lib/libcastortapegatewayprotocol.so.2.1
%attr(-,root,root) /usr/lib/libcastortapegatewayprotocol.so.2.1.9.8
%attr(-,root,root) /usr/lib/libcastortapepython.so.2.1
%attr(-,root,root) /usr/lib/libcastortapepython.so.2.1.9.8
%attr(-,root,root) /usr/lib/libcastortapeutils.so.2.1
%attr(-,root,root) /usr/lib/libcastortapeutils.so.2.1.9.8
%endif
%post -n castor-lib-tape
# call to ldconfig after we installed new libraries
/sbin/ldconfig
%postun -n castor-lib-tape
# call to ldconfig after we uninstalled libraries
/sbin/ldconfig
%endif

%if ! %compiling_client
%package -n castor-gridftp-dsi-common
Summary: Cern Advanced mass STORage
Group: Application/Castor
%description -n castor-gridftp-dsi-common
castor (Cern Advanced STORage system) - Commonnalities between internal and external CASTOR2 gridftp2 DSI module
%files -n castor-gridftp-dsi-common
%defattr(-,root,root)
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-gridftp-dsi-common
%endif

%if ! %compiling_client
%package -n castor-gridftp-dsi-int
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: vdt_globus_data_server,vdt_globus_essentials,castor-gridftp-dsi-common
%description -n castor-gridftp-dsi-int
castor (Cern Advanced STORage system) - Internal CASTOR2 gridftp2 DSI module
%files -n castor-gridftp-dsi-int
%defattr(-,root,root)
%attr(-,root,bin) %dir /var/log
%ifarch x86_64
%attr(0755,root,root) /opt/globus/lib/libglobus_gridftp_server_CASTOR2int_gcc64dbg.so
%attr(0755,root,root) /opt/globus/lib/libglobus_gridftp_server_CASTOR2int_gcc64dbg.so.2.1
%attr(0755,root,root) /opt/globus/lib/libglobus_gridftp_server_CASTOR2int_gcc64dbg.so.2.1.9.8
%else
%attr(0755,root,root) /opt/globus/lib/libglobus_gridftp_server_CASTOR2int_gcc32dbg.so
%attr(0755,root,root) /opt/globus/lib/libglobus_gridftp_server_CASTOR2int_gcc32dbg.so.2.1
%attr(0755,root,root) /opt/globus/lib/libglobus_gridftp_server_CASTOR2int_gcc32dbg.so.2.1.9.8
%endif
%post -n castor-gridftp-dsi-int
/bin/touch /var/log/gridftp.log
/bin/touch /var/log/globus-gridftp.log
/bin/chown stage:st /var/log/gridftp.log
/bin/chown stage:st /var/log/globus-gridftp.log
%endif

%if ! %compiling_client
%package -n castor-gridftp-dsi-ext
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib,xinetd,vdt_globus_data_server,vdt_globus_essentials,castor-gridftp-dsi-common
%description -n castor-gridftp-dsi-ext
castor (Cern Advanced STORage system) - External CASTOR2 gridftp2 DSI module
%files -n castor-gridftp-dsi-ext
%defattr(-,root,root)
%attr(-,root,bin) %dir /var/log
%ifarch x86_64
%attr(0755,root,root) /opt/globus/lib/libglobus_gridftp_server_CASTOR2ext_gcc64dbg.so
%attr(0755,root,root) /opt/globus/lib/libglobus_gridftp_server_CASTOR2ext_gcc64dbg.so.2.1
%attr(0755,root,root) /opt/globus/lib/libglobus_gridftp_server_CASTOR2ext_gcc64dbg.so.2.1.9.8
%attr(0644,root,root) %config(noreplace) /etc/xinetd.d/gsiftp
%else
%attr(0755,root,root) /opt/globus/lib/libglobus_gridftp_server_CASTOR2ext_gcc32dbg.so
%attr(0755,root,root) /opt/globus/lib/libglobus_gridftp_server_CASTOR2ext_gcc32dbg.so.2.1
%attr(0755,root,root) /opt/globus/lib/libglobus_gridftp_server_CASTOR2ext_gcc32dbg.so.2.1.9.8
%attr(0644,root,root) %config(noreplace) /etc/xinetd.d/gsiftp
%endif
%post -n castor-gridftp-dsi-ext
if [ "`grep gsiftp /etc/services`" = "" ]; then 
    echo "gsiftp          2811/tcp # gridftp server port" >> /etc/services
fi
/sbin/service xinetd condrestart > /dev/null 2>&1 || :
%postun -n castor-gridftp-dsi-ext
/sbin/service xinetd reload > /dev/null 2>&1 || :
%endif

%if ! %compiling_client
%package -n castor-gridftp-dsi-xroot
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib,vdt_globus_data_server,vdt_globus_essentials,castor-gridftp-dsi-common,xrootd
%description -n castor-gridftp-dsi-xroot
castor (Cern Advanced STORage system) - External CASTOR2 gridftp2 DSI module with xroot support
%files -n castor-gridftp-dsi-xroot
%defattr(-,root,root)
%attr(-,root,bin) %dir /var/log
%ifarch x86_64
%attr(0755,root,root) /opt/globus/lib/libglobus_gridftp_server_CASTOR2xroot_gcc64dbg.so
%attr(0755,root,root) /opt/globus/lib/libglobus_gridftp_server_CASTOR2xroot_gcc64dbg.so.2.1
%attr(0755,root,root) /opt/globus/lib/libglobus_gridftp_server_CASTOR2xroot_gcc64dbg.so.2.1.9.8
%else
%attr(0755,root,root) /opt/globus/lib/libglobus_gridftp_server_CASTOR2xroot_gcc32dbg.so
%attr(0755,root,root) /opt/globus/lib/libglobus_gridftp_server_CASTOR2xroot_gcc32dbg.so.2.1
%attr(0755,root,root) /opt/globus/lib/libglobus_gridftp_server_CASTOR2xroot_gcc32dbg.so.2.1.9.8
%endif
%post -n castor-gridftp-dsi-xroot
/bin/touch /var/log/gridftp.log
/bin/touch /var/log/globus-gridftp.log
/bin/chown stage:st /var/log/gridftp.log
/bin/chown stage:st /var/log/globus-gridftp.log
%postun -n castor-gridftp-dsi-xroot
/sbin/service xinetd reload > /dev/null 2>&1 || :
%endif

%if ! %compiling_client
%package -n castor-mighunter-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,castor-lib-tape
%description -n castor-mighunter-server
castor (Cern Advanced STORage system) - Migration Hunter Daemon
%files -n castor-mighunter-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/mighunterd.8castor
%attr(-,root,bin) %dir /var/log/castor
%attr(0755,root,root) /etc/init.d/mighunterd
%attr(0644,root,root) /etc/sysconfig/mighunterd.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-mighunter-server
%attr(0750,root,root) /usr/bin/mighunterd
%attr(0644,root,root) /etc/castor/policies/migration.py.example
%attr(0644,root,root) /etc/castor/policies/stream.py.example
%post -n castor-mighunter-server
/sbin/chkconfig --add mighunterd
/sbin/service mighunterd condrestart > /dev/null 2>&1 || :
%preun -n castor-mighunter-server
if [ "$1" = 0 ]; then
    /sbin/service mighunterd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del mighunterd
fi
%pre -n castor-mighunter-server
if [ -f /etc/rc.d/init.d/mighunter ]; then
    /sbin/service mighunter stop > /dev/null 2>&1 || :
fi
# Move old log files to /var/log/castor
if [ -d /var/spool/mighunter ]; then
    /bin/mkdir /var/log/castor 2>/dev/null
    for src in `ls /var/spool/mighunter/log.*.gz 2>/dev/null`; do
        dest=`basename $src | sed 's/log/mighunterd.log/'`
        /bin/mv $src /var/log/castor/$dest 2>/dev/null
    done
    /bin/mv /var/spool/mighunter/log /var/log/castor/mighunterd.log 2>/dev/null
    /bin/chmod 644 /var/log/castor/mighunterd.* 2>/dev/null
    # Correct the selinux context of the new log files
    if [ -x /usr/bin/chcon ]; then
      /usr/bin/chcon -R --reference=/var/log/castor /var/log/castor > /dev/null 2>&1
    fi
    # Remove old log directory
    /bin/rm -rf /var/spool/mighunter 2>/dev/null || :
fi
%endif

%if ! %compiling_client
%package -n castor-rechandler-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,castor-lib-tape
%description -n castor-rechandler-server
castor (Cern Advanced STORage system) - Recall Handler Daemon
%files -n castor-rechandler-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/rechandlerd.8castor
%attr(-,root,bin) %dir /var/log/castor
%attr(0755,root,root) /etc/init.d/rechandlerd
%attr(0644,root,root) /etc/sysconfig/rechandlerd.example
%attr(0644,root,root) /etc/castor/policies/rechandler.py.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-rechandler-server
%attr(0750,root,root) /usr/bin/rechandlerd
%post -n castor-rechandler-server
/sbin/chkconfig --add rechandlerd
/sbin/service rechandlerd condrestart > /dev/null 2>&1 || :
%preun -n castor-rechandler-server
if [ "$1" = 0 ]; then
    /sbin/service rechandlerd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del rechandlerd
fi
%pre -n castor-rechandler-server
if [ -f /etc/rc.d/init.d/rechandler ]; then
    /sbin/service rechandler stop > /dev/null 2>&1 || :
fi
# Move old log files to /var/log/castor
if [ -d /var/spool/rechandler ]; then
    /bin/mkdir /var/log/castor 2>/dev/null
    for src in `ls /var/spool/rechandler/log.*.gz 2>/dev/null`; do
        dest=`basename $src | sed 's/log/rechandlerd.log/'`
        /bin/mv $src /var/log/castor/$dest 2>/dev/null
    done
    /bin/mv /var/spool/rechandler/log /var/log/castor/rechandlerd.log 2>/dev/null
    /bin/chmod 644 /var/log/castor/rechandlerd.* 2>/dev/null
    # Correct the selinux context of the new log files
    if [ -x /usr/bin/chcon ]; then
      /usr/bin/chcon -R --reference=/var/log/castor /var/log/castor > /dev/null 2>&1
    fi
    # Remove old log directory
    /bin/rm -rf /var/spool/rechandler 2>/dev/null || :
fi
%endif

%if ! %compiling_client
%package -n castor-csec
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: castor-lib,vdt_globus_essentials,glite-security-voms-api-c
%description -n castor-csec
castor (Cern Advanced STORage system) - Csec library
%files -n castor-csec
%defattr(-,root,root)
%ifarch x86_64
%attr(-,root,root) /usr/lib64/libCsec_plugin_GSI.so.2.1
%attr(-,root,root) /usr/lib64/libCsec_plugin_GSI.so.2.1.9.8
%attr(-,root,root) /usr/lib64/libCsec_plugin_GSI.so
%attr(-,root,root) /usr/lib64/libCsec_plugin_GSI_thread.so.2.1
%attr(-,root,root) /usr/lib64/libCsec_plugin_GSI_thread.so.2.1.9.8
%attr(-,root,root) /usr/lib64/libCsec_plugin_GSI_thread.so
%attr(-,root,root) /usr/lib64/libCsec_plugin_ID.so.2.1
%attr(-,root,root) /usr/lib64/libCsec_plugin_ID.so.2.1.9.8
%attr(-,root,root) /usr/lib64/libCsec_plugin_ID.so
%attr(-,root,root) /usr/lib64/libCsec_plugin_KRB5.so.2.1
%attr(-,root,root) /usr/lib64/libCsec_plugin_KRB5.so.2.1.9.8
%attr(-,root,root) /usr/lib64/libCsec_plugin_KRB5.so
%else
%attr(-,root,root) /usr/lib/libCsec_plugin_GSI.so.2.1
%attr(-,root,root) /usr/lib/libCsec_plugin_GSI.so.2.1.9.8
%attr(-,root,root) /usr/lib/libCsec_plugin_GSI.so
%attr(-,root,root) /usr/lib/libCsec_plugin_GSI_thread.so.2.1
%attr(-,root,root) /usr/lib/libCsec_plugin_GSI_thread.so.2.1.9.8
%attr(-,root,root) /usr/lib/libCsec_plugin_GSI_thread.so
%attr(-,root,root) /usr/lib/libCsec_plugin_ID.so.2.1
%attr(-,root,root) /usr/lib/libCsec_plugin_ID.so.2.1.9.8
%attr(-,root,root) /usr/lib/libCsec_plugin_ID.so
%attr(-,root,root) /usr/lib/libCsec_plugin_KRB5.so.2.1
%attr(-,root,root) /usr/lib/libCsec_plugin_KRB5.so.2.1.9.8
%attr(-,root,root) /usr/lib/libCsec_plugin_KRB5.so
%endif
%endif

%if ! %compiling_client
%package -n castor-tapebridge-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,castor-lib-tape
Obsoletes: castor-aggregator-server
%description -n castor-tapebridge-server
castor (Cern Advanced STORage system) - Tape Bridge Daemon
%files -n castor-tapebridge-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/tapebridged.8castor
%attr(-,root,bin) %dir /var/log/castor
%attr(0750,root,root) /usr/bin/tapebridged
%attr(0644,root,root) /etc/sysconfig/tapebridged.example
%attr(0755,root,root) /etc/init.d/tapebridged
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-tapebridge-server
%post -n castor-tapebridge-server
/sbin/chkconfig --add tapebridged
/sbin/service tapebridged condrestart > /dev/null 2>&1 || :
%preun -n castor-tapebridge-server
if [ "$1" = 0 ]; then
    /sbin/service tapebridged stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del tapebridged
fi
%endif

%if ! %compiling_client
%package -n castor-tapebridge-client
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,castor-lib-tape
Obsoletes: castor-aggregator-client
%description -n castor-tapebridge-client
castor (Cern Advanced STORage system) - Tape Bridge Clients
%files -n castor-tapebridge-client
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/dumptp.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/readtp.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/writetp.1castor
%attr(0750,root,root) /usr/bin/dumptp
%attr(0750,root,root) /usr/bin/readtp
%attr(0750,root,root) /usr/bin/writetp
%endif

%if ! %compiling_client
%package -n castor-logprocessor-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,cx_Oracle
%description -n castor-logprocessor-server
castor (Cern Advanced STORage system) - Log Processor Daemon
%files -n castor-logprocessor-server
%defattr(-,root,root)
%attr(-,root,bin) %dir /var/log/castor
%attr(-,root,bin) %dir /var/log/dlf
%attr(0755,root,root) /usr/bin/logprocessord
%attr(0644,root,root) /usr/lib/log-processor/DLF.py
%attr(0644,root,root) /usr/lib/log-processor/LoggingCommon.py
%attr(0755,root,root) /etc/init.d/logprocessord
%attr(0644,root,root) /etc/sysconfig/logprocessord.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-logprocessor-server
%attr(0640,root,root) /etc/castor/DLFCONFIG.example
%attr(0640,root,root) /etc/castor/logprocessord.conf.example
%post -n castor-logprocessor-server
/sbin/chkconfig --add logprocessord
/sbin/service logprocessord condrestart > /dev/null 2>&1 || :
%preun -n castor-logprocessor-server
if [ "$1" = 0 ]; then
    /sbin/service logprocessord stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del logprocessord
fi
%pre -n castor-logprocessor-server
# Remove old log directory
if [ -d /var/spool/dlf ]; then
    /bin/rm -rf /var/spool/dlf 2>/dev/null || :
fi
%endif

%if ! %compiling_client
%package -n castor-tapegateway-server
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate,castor-lib-oracle,castor-lib-tape
%description -n castor-tapegateway-server
castor (Cern Advanced STORage system) - Tape Gateway Daemon
%files -n castor-tapegateway-server
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man8/tapegatewayd.8castor
%attr(-,root,bin) %dir /var/log/castor
%attr(0755,root,root) /etc/init.d/tapegatewayd
%attr(0644,root,root) /etc/sysconfig/tapegatewayd.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-tapegateway-server
%attr(0750,root,root) /usr/bin/tapegatewayd
%attr(0644,root,root) /etc/castor/policies/migrationRetry.py.example
%attr(0644,root,root) /etc/castor/policies/recallRetry.py.example
%post -n castor-tapegateway-server
/sbin/chkconfig --add tapegatewayd
/sbin/service tapegatewayd condrestart > /dev/null 2>&1 || :
%preun -n castor-tapegateway-server
if [ "$1" = 0 ]; then
    /sbin/service tapegatewayd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del tapegatewayd
fi
%endif

%else
%if ! %compiling_client
%package -n castor-tape-server-nostk
Summary: Cern Advanced mass STORage
Group: Application/Castor
Requires: logrotate
%description -n castor-tape-server-nostk
castor (Cern Advanced STORage system) - Tape server
%files -n castor-tape-server-nostk
%defattr(-,root,root)
%attr(0644,root,bin) %doc /usr/share/man/man1/smc.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/tape_oper.1castor
%attr(0644,root,bin) %doc /usr/share/man/man8/taped.8castor
%attr(0644,root,bin) %doc /usr/share/man/man1/tplabel.1castor
%attr(0644,root,bin) %doc /usr/share/man/man1/tpdump.1castor
%attr(-,root,bin) %dir /var/log/castor
%attr(0640,root,root) /etc/castor/TPCONFIG.example
%attr(0755,root,root) /etc/init.d/taped
%attr(0644,root,root) /etc/sysconfig/taped.example
%attr(0644,root,root) %config(noreplace) /etc/logrotate.d/castor-tape-server
%attr(0750,root,root) /usr/bin/confdrive
%attr(0750,root,root) /usr/bin/mounttape
%attr(0750,root,root) /usr/bin/posovl
%attr(0750,root,root) /usr/bin/rlstape
%attr(6755,root,root) /usr/bin/smc
%attr(0750,root,root) /usr/bin/taped
%attr(0755,root,root) /usr/bin/tpdump
%attr(0755,root,root) /usr/bin/tplabel
%post -n castor-tape-server-nostk
/sbin/chkconfig --add taped
/sbin/service taped condrestart > /dev/null 2>&1 || :
%preun -n castor-tape-server-nostk
if [ "$1" = 0 ]; then
    /sbin/service taped stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del taped
fi
%pre -n castor-tape-server-nostk
if [ -f /etc/rc.d/init.d/tpdaemon ]; then
    /sbin/service tpdaemon stop > /dev/null 2>&1 || :
fi
# Move old log files to /var/log/castor
if [ -d /var/spool/tape ]; then
    /bin/mkdir /var/log/castor 2>/dev/null
    for src in `ls /var/spool/tape/log.*.gz 2>/dev/null`; do
        dest=`basename $src | sed 's/log/taped.log/'`
        /bin/mv $src /var/log/castor/$dest 2>/dev/null
    done
    /bin/mv /var/spool/tape/log /var/log/castor/taped.log 2>/dev/null
    /bin/chmod 644 /var/log/castor/taped.* 2>/dev/null
    # Correct the selinux context of the new log files
    if [ -x /usr/bin/chcon ]; then
      /usr/bin/chcon -R --reference=/var/log/castor /var/log/castor > /dev/null 2>&1
    fi
    # Remove old log directory
    /bin/rm -rf /var/spool/tape 2>/dev/null || :
fi
%endif

%endif
